"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var util_1 = require("../util");
var definition_1 = require("../definition");
/**
 * @action-builder
 * @stable [09.05.2020]
 */
var DictionariesActionBuilder = /** @class */ (function () {
    function DictionariesActionBuilder() {
    }
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @returns {string}
     */
    DictionariesActionBuilder.buildLoadActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.DICTIONARY_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [09.05.2020]
     * @returns {string}
     */
    DictionariesActionBuilder.buildDestroyActionType = function () {
        return util_1.toActionPrefix('all') + "." + definition_1.DICTIONARY_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @returns {string}
     */
    DictionariesActionBuilder.buildLoadDoneActionType = function (section) {
        return redux_effects_promise_1.EffectsActionBuilder.buildDoneActionType(util_1.toActionPrefix(section) + "." + definition_1.DICTIONARY_LOAD_ACTION_TYPE);
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @returns {string}
     */
    DictionariesActionBuilder.buildLoadErrorActionType = function (section) {
        return redux_effects_promise_1.EffectsActionBuilder.buildErrorActionType(util_1.toActionPrefix(section) + "." + definition_1.DICTIONARY_LOAD_ACTION_TYPE);
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @returns {string}
     */
    DictionariesActionBuilder.buildSetActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.DICTIONARY_SET_ACTION_TYPE;
    };
    /**
     * @stable [09.05.2020]
     * @returns {IEffectsAction}
     */
    DictionariesActionBuilder.buildDestroyAction = function () {
        return redux_effects_promise_1.EffectsAction.create(DictionariesActionBuilder.buildDestroyActionType());
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @param {TData} data
     * @returns {IEffectsAction}
     */
    DictionariesActionBuilder.buildLoadAction = function (section, data) {
        var plainAction = this.buildLoadPlainAction(section, data);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @param {TData[] | TData} data
     * @returns {IEffectsAction}
     */
    DictionariesActionBuilder.buildSetAction = function (section, data) {
        var plainAction = this.buildSetPlainAction(section, data);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [30.03.2020]
     * @param {string} section
     * @param {TData} data
     * @returns {IEffectsAction}
     */
    DictionariesActionBuilder.buildLoadPlainAction = function (section, data) {
        return {
            type: this.buildLoadActionType(section),
            data: util_1.applySection(section, data),
        };
    };
    /**
     * @stable [09.05.2020]
     * @param {string} section
     * @param {TData[] | TData} data
     * @returns {IEffectsAction}
     */
    DictionariesActionBuilder.buildSetPlainAction = function (section, data) {
        return {
            type: this.buildSetActionType(section),
            data: util_1.applySection(section, data),
        };
    };
    return DictionariesActionBuilder;
}());
exports.DictionariesActionBuilder = DictionariesActionBuilder;
//# sourceMappingURL=dictionaries-action.builder.js.map