"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var util_1 = require("../util");
var definition_1 = require("../definition");
/**
 * @action-builder
 * @stable [08.05.2020]
 */
var FilterActionBuilder = /** @class */ (function () {
    function FilterActionBuilder() {
    }
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {string}
     */
    FilterActionBuilder.buildApplyActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.FILTER_APPLY_ACTION_TYPE;
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {string}
     */
    FilterActionBuilder.buildChangeActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.FILTER_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {string}
     */
    FilterActionBuilder.buildDeactivateActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.FILTER_DEACTIVATE_ACTION_TYPE;
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {string}
     */
    FilterActionBuilder.buildActivateActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.FILTER_ACTIVATE_ACTION_TYPE;
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {string}
     */
    FilterActionBuilder.buildDestroyActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + definition_1.FILTER_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildApplyPlainAction = function (section) {
        return { type: this.buildApplyActionType(section), data: util_1.applySection(section) };
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildActivatePlainAction = function (section) {
        return { type: this.buildActivateActionType(section), data: util_1.applySection(section) };
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildDeactivatePlainAction = function (section) {
        return { type: this.buildDeactivateActionType(section), data: util_1.applySection(section) };
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @param {string} query
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildChangePlainAction = function (section, query) {
        var fluxEntity = { query: query };
        return { type: this.buildChangeActionType(section), data: util_1.applySection(section, fluxEntity) };
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildDestroyPlainAction = function (section) {
        return { type: this.buildDestroyActionType(section), data: util_1.applySection(section) };
    };
    /**
     * @stable [27.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FilterActionBuilder.buildDestroyAction = function (section) {
        var plainAction = this.buildDestroyPlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    return FilterActionBuilder;
}());
exports.FilterActionBuilder = FilterActionBuilder;
//# sourceMappingURL=filter-action.builder.js.map