import { IEffectsAction } from 'redux-effects-promise';
import { IApiEntity } from '../definition';
/**
 * @action-builder
 * @stable [08.05.2020]
 */
export declare class FormActionBuilder {
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDestroyActionType(section: string): string;
    /**
     * @stable [26.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildClearActionType(section: string): string;
    /**
     * @stable [02.10.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildChangeActionType(section: string): string;
    /**
     * @stable [20.12.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDefaultChangeActionType(section: string): string;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildValidActionType(section: string): string;
    /**
     * @stable [14.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildActiveValueActionType(section: string): string;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @returns {string}
     */
    static buildInactiveValueActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitActionType(section: string): string;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildProgressActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitDoneActionType(section: string): string;
    /**
     * @stable [12.04.2020]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitFinishActionType(section: string): string;
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildSubmitErrorActionType(section: string): string;
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildSubmitDoneAction(section: string): IEffectsAction;
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetAction(section: string): IEffectsAction;
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildProgressAction(section: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    static buildValidAction(section: string, valid: boolean): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildSubmitFinishAction(section: string): IEffectsAction;
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildDestroyAction(section: string): IEffectsAction;
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildChangesAction<TData = {}>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildDefaultChangesAction<TData = {}>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    static buildClearPlainAction(section: string, fieldName: string): IEffectsAction;
    /**
     * @stable [11.09.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildResetPlainAction(section: string): IEffectsAction;
    /**
     * @stable [01.03.2020]
     * @param {string} section
     * @param {IApiEntity} apiEntity
     * @returns {IEffectsAction}
     */
    static buildSubmitPlainAction(section: string, apiEntity: IApiEntity): IEffectsAction;
    /***
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    static buildValidPlainAction(section: string, valid: boolean): IEffectsAction;
    /**
     * @stable [12.04.2020]
     * @param {string} section
     * @param {number} payload
     * @returns {IEffectsAction}
     */
    static buildActiveValuePlainAction(section: string, payload: number): IEffectsAction;
    /**
     * @stable [12.04.2020]
     * @param {string} section
     * @param {number} payload
     * @returns {IEffectsAction}
     */
    static buildInactiveValuePlainAction(section: string, payload: number): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildSubmitFinishPlainAction(section: string): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildChangesPlainAction<TData = {}>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [01.04.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    static buildDefaultChangesPlainAction<TData = {}>(section: string, changes: TData): IEffectsAction;
    /**
     * @stable [08.05.2020]
     * @param {IKeyValue} fields
     * @returns {IFluxFieldsChangesEntity}
     */
    private static buildChangesPayload;
}
