"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var generic_component_1 = require("./generic.component");
var di_1 = require("../../di");
var EnhancedGenericComponent = /** @class */ (function (_super) {
    __extends(EnhancedGenericComponent, _super);
    /**
     * @stable [21.04.2020]
     * @param {TProps} props
     */
    function EnhancedGenericComponent(props) {
        var _this = _super.call(this, props) || this;
        _this.plugins = [];
        _this.initPlugins();
        return _this;
    }
    /**
     * @stable [21.04.2020]
     */
    EnhancedGenericComponent.prototype.componentDidMount = function () {
        this.plugins.forEach(function (plugin) { return util_1.isFn(plugin.componentDidMount) && plugin.componentDidMount(); });
    };
    /**
     * @stable [21.04.2020]
     */
    EnhancedGenericComponent.prototype.componentWillUnmount = function () {
        this.plugins.forEach(function (plugin) { return util_1.isFn(plugin.componentWillUnmount) && plugin.componentWillUnmount(); });
    };
    /**
     * @stable [21.04.2020]
     * @param {Readonly<TProps extends IEnhancedGenericComponentProps>} prevProps
     * @param {Readonly<TState>} prevState
     * @param {never} prevContext
     */
    EnhancedGenericComponent.prototype.componentDidUpdate = function (prevProps, prevState, prevContext) {
        this.plugins.forEach(function (plugin) { return util_1.isFn(plugin.componentDidUpdate) && plugin.componentDidUpdate(prevProps, prevState, prevContext); });
    };
    /**
     * @stable [21.04.2020]
     * @param {Readonly<TProps extends IEnhancedGenericComponentProps>} prevProps
     * @param {Readonly<TState>} prevState
     */
    EnhancedGenericComponent.prototype.getSnapshotBeforeUpdate = function (prevProps, prevState) {
        this.plugins.forEach(function (plugin) {
            return util_1.isFn(plugin.getSnapshotBeforeUpdate) && plugin.getSnapshotBeforeUpdate(prevProps, prevState);
        });
        return null;
    };
    /**
     * @stable [10.04.2020]
     * @param {GenericPluginCtorT | IGenericPlugin} pluginObject
     */
    EnhancedGenericComponent.prototype.registerPlugin = function (pluginObject) {
        if (R.isNil(pluginObject)) {
            return;
        }
        this.plugins.push(util_1.isFn(pluginObject)
            ? Reflect.construct(pluginObject, [this])
            : pluginObject);
    };
    /**
     * @stable [21.04.2020]
     */
    EnhancedGenericComponent.prototype.initPlugins = function () {
        var _this = this;
        var plugins = this.uiPlugins;
        if (!util_1.isObjectEmpty(plugins)) {
            var dynamicPluginsFactories = plugins.get(this.constructor);
            if (util_1.isObjectNotEmpty(dynamicPluginsFactories)) {
                dynamicPluginsFactories.forEach(function (dynamicPluginFactory) { return _this.registerPlugin(dynamicPluginFactory(_this)); });
            }
        }
        [].concat(this.props.plugins || []).forEach(this.registerPlugin, this);
    };
    Object.defineProperty(EnhancedGenericComponent.prototype, "uiPlugins", {
        /**
         * @stable [21.04.2020]
         * @returns {GenericPluginsMapT}
         */
        get: function () {
            return this.$uiPlugins = this.$uiPlugins || di_1.getUiPlugins();
        },
        enumerable: true,
        configurable: true
    });
    return EnhancedGenericComponent;
}(generic_component_1.GenericComponent));
exports.EnhancedGenericComponent = EnhancedGenericComponent;
//# sourceMappingURL=enhanced-generic.component.js.map