"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../util");
var di_1 = require("../../di");
var connector_factory_1 = require("./connector.factory");
var logger = ts_smart_logger_1.LoggerFactory.makeLogger('universal-connector.decorator');
/**
 * @stable - 23.04.2018
 * @param {IBasicConnectorEntity<TStoreEntity>} config
 * @returns {(target: IContainerClassEntity) => void}
 */
exports.basicConnector = function (config) {
    return function (target) {
        var finalTarget = target;
        var section = util_1.ifNotNilThanValue(target.defaultProps, function (defaultProps) { return defaultProps.sectionName; });
        if (section) {
            di_1.getDynamicSections().set(section, config);
            finalTarget = di_1.getConnectorContainerFactory().fromTarget(target, section);
        }
        else {
            logger.warn("[$basicConnector] The sectionName is not defined for " + (target.name ||
                target) + ". The init and destroy actions are disabled.");
        }
        di_1.getDynamicRoutes().set(connector_factory_1.connectorFactory.apply(void 0, [finalTarget].concat(config.mappers)), config);
    };
};
/**
 * @stable - 23.04.2018
 * @param {IConnectorEntity<TStoreEntity extends IUniversalStoreEntity, TAccessConfig>} config
 * @returns {(target: IContainerClassEntity) => void}
 */
exports.connector = function (config) { return exports.basicConnector(config); };
//# sourceMappingURL=connector.decorator.js.map