import * as React from 'react';
import { AnyT } from '../../../definitions.interface';
import { ChangeEventT, FieldComposedInputAttributesT, IBaseEvent, IField, IFieldProps, IFieldState, IFocusEvent, IKeyboardProps, IMaskedInputCtor, InputElementT } from '../../../definition';
import { DelayedTask } from '../../../util';
import { EnhancedGenericComponent } from '../../base/enhanced-generic.component';
export declare class Field<TProps extends IFieldProps, TState extends IFieldState> extends EnhancedGenericComponent<TProps, TState> implements IField<TProps, TState> {
    protected readonly inputRef: React.RefObject<HTMLInputElement | HTMLTextAreaElement | IMaskedInputCtor>;
    protected caretBlinkingTask: DelayedTask;
    protected keyboardListenerUnsubscriber: () => void;
    protected readonly inputMirrorRef: React.RefObject<HTMLElement>;
    private readonly keyboardRef;
    /**
     * @stable [21.06.2020]
     * @param {TProps} originalProps
     */
    constructor(originalProps: TProps);
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    render(): JSX.Element;
    /**
     * @stable [21.06.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [21.06.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [21.06.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    componentDidUpdate(prevProps: TProps, prevState: TState): void;
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     */
    onChange(event: ChangeEventT): void;
    /**
     * @stable [21.06.2020]
     * @param {TValue} currentRawValue
     */
    onChangeManually<TValue = AnyT>(currentRawValue: TValue): void;
    /**
     * @stable [21.06.2020]
     */
    setFocus(): void;
    /**
     * @stable [21.06.2020]
     */
    clearValue(): void;
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     * @returns {AnyT}
     */
    getRawValueFromEvent(event: ChangeEventT): AnyT;
    /**
     * @stable [17.06.2020]
     * @returns {AnyT}
     */
    readonly value: AnyT;
    /**
     * @stable [03.06.2020]
     * @returns {InputElementT}
     */
    readonly input: InputElementT;
    /**
     * @stable [05.06.2020]
     */
    protected removeFocus(): void;
    protected readonly displayValueElement: React.ReactNode;
    private readonly keyboardElement;
    /**
     * @stable [21.06.2020]
     * @param {IFocusEvent} event
     */
    protected onFocus(event: IFocusEvent): void;
    protected openVirtualKeyboard(): void;
    /**
     * @stable [17.06.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [03.06.2020]
     * @param {AnyT} currentRawValue
     */
    protected onChangeValue(currentRawValue: AnyT): void;
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @param {boolean} forceApplyValue
     * @returns {AnyT}
     */
    protected getDecoratedDisplayValue(value: AnyT, forceApplyValue?: boolean): AnyT;
    /**
     * @stable [17.06.2020]
     * @returns {AnyT}
     */
    protected readonly decoratedDisplayValue: AnyT;
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected decorateDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [18.05.2020]
     * @returns {FieldComposedInputAttributesT}
     */
    protected getInputElementProps(): FieldComposedInputAttributesT;
    /**
     * @stable [19.06.2020]
     * @returns {JSX.Element}
     */
    protected readonly selfElement: JSX.Element;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected readonly actionsElement: JSX.Element;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected readonly inputWrapperElement: JSX.Element;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected getInputElement(): JSX.Element;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    protected getLabel(): string;
    /**
     * @stable [22.06.2020]
     * @returns {Array<string | RegExp>}
     */
    protected getFieldMask(): Array<string | RegExp>;
    /**
     * @stable [21.06.2020]
     * @returns {IKeyboardProps}
     */
    protected getKeyboardProps(): IKeyboardProps;
    /**
     * @stable [10.08.2020]
     * @protected
     */
    protected getComponentsSettingsProps(): TProps;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected readonly inputAttachmentElement: JSX.Element;
    /**
     * @stable [16.06.2020]
     * @returns {JSX.Element}
     */
    protected readonly attachmentElement: JSX.Element;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected readonly mirrorInputElement: JSX.Element;
    /**
     * @stable [19.05.2020]
     * @returns {JSX.Element}
     */
    protected readonly progressInfoElement: JSX.Element;
    protected readonly isCursorUsed: boolean;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    protected readonly isKeyboardAndCursorUsed: boolean;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected readonly emptyValue: AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected readonly originalEmptyValue: AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected readonly defaultValue: AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected readonly displayValue: AnyT;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected isKeyboardOpen(): boolean;
    /**
     * @stable [19.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    protected isValueObject(value: AnyT): boolean;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    protected readonly isPlainValueApplied: boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected readonly isValuePresent: boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean | undefined}
     */
    protected readonly isKeyboardUsed: boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected readonly isRequired: boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected readonly isDisabled: boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected readonly isValueNotPresent: boolean;
    /**
     * @stable [03.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    protected isValueDefined(value: AnyT): boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected readonly isInputValid: boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected readonly isFocusPrevented: boolean;
    /**
     * @stable [05.06.2020]
     * @returns {boolean}
     */
    protected readonly isBusy: boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected readonly isFieldRendered: boolean;
    /**
     * @stable [02.08.2020]
     */
    protected readonly isReadOnly: boolean;
    /**
     * @stable [02.08.2020]
     */
    protected readonly isInactive: boolean;
    /**
     * @stable [02.08.2020]
     */
    protected readonly isActive: boolean;
    /**
     * @stable [22.06.2020]
     * @returns {boolean}
     */
    protected readonly isDisplayValueDefined: boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected readonly hasInput: boolean;
    /**
     * @stable [03.06.2020]
     * @returns {TProps}
     */
    protected readonly componentsSettingsProps: TProps;
    /**
     * @stable [21.06.2020]
     */
    private refreshCaretPosition;
    /**
     * @stable [21.06.2020]
     */
    private setCaretVisibility;
    /**
     * @stable [21.06.2020]
     * @param {AnyT} rawValue
     */
    private validateField;
    /**
     * @stable [21.06.2020]
     * @param {AnyT} value
     * @returns {string}
     */
    private validateValueAndSetCustomValidity;
    /**
     * @stable [21.06.2020]
     */
    private closeVirtualKeyboard;
    /**
     * @stable [21.06.2020]
     * @param {IBaseEvent} event
     */
    private onDocumentClickHandler;
    /**
     * @stable [21.06.2020]
     */
    private onCloseVirtualKeyboard;
    /**
     * @stable [21.06.2020]
     * @param {string} rawValue
     */
    private onKeyboardChange;
    /**
     * @stable [21.06.2020]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    private messageElement;
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    private readonly labelElement;
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    private readonly prefixLabelElement;
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    private readonly inputCaretElement;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    private readonly title;
    /**
     * @stable [21.06.2020]
     * @returns {number}
     */
    private readonly caretPosition;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private readonly isErrorMessageRendered;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private readonly areManualChangesNotPrevented;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private readonly isChangeable;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private readonly isInvalid;
    /**
     * @stable [22.06.2020]
     * @returns {boolean}
     */
    private readonly isFocused;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private readonly isInlineKeyboard;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    private readonly inputValidationMessage;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    private readonly error;
}
