"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var definitions_interface_1 = require("../../../definitions.interface");
var definition_1 = require("../../../definition");
var util_1 = require("../../../util");
var info_component_1 = require("../../info/info.component");
var enhanced_generic_component_1 = require("../../base/enhanced-generic.component");
var keyboard_component_1 = require("../../keyboard/keyboard.component");
var Field = /** @class */ (function (_super) {
    __extends(Field, _super);
    /**
     * @stable [21.06.2020]
     * @param {TProps} originalProps
     */
    function Field(originalProps) {
        var _this = _super.call(this, originalProps) || this;
        /**/
        _this.inputRef = React.createRef();
        /**/
        _this.inputMirrorRef = React.createRef(); // TODO -> private
        _this.keyboardRef = React.createRef();
        _this.state = {};
        _this.closeVirtualKeyboard = _this.closeVirtualKeyboard.bind(_this);
        _this.onChangeManually = _this.onChangeManually.bind(_this);
        _this.onClick = _this.onClick.bind(_this);
        _this.onCloseVirtualKeyboard = _this.onCloseVirtualKeyboard.bind(_this);
        _this.onDocumentClickHandler = _this.onDocumentClickHandler.bind(_this);
        _this.onFocus = _this.onFocus.bind(_this);
        _this.onKeyboardChange = _this.onKeyboardChange.bind(_this);
        if (_this.isKeyboardAndCursorUsed) {
            var caretBlinkingFrequency = _this.mergedProps.caretBlinkingFrequency;
            _this.caretBlinkingTask = new util_1.DelayedTask(_this.setCaretVisibility.bind(_this), caretBlinkingFrequency || 400, true);
        }
        return _this;
    }
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    Field.prototype.render = function () {
        var _this = this;
        var message = this.originalProps.message;
        return (React.createElement("div", { className: this.getFieldClassName(), onClick: this.domAccessor.cancelEvent },
            this.originalChildren,
            this.displayValueElement,
            this.selfElement,
            util_1.ConditionUtils.ifNotNilThanValue(message, function () { return _this.messageElement(message); }),
            util_1.ConditionUtils.orNull(this.isErrorMessageRendered, function () { return _this.messageElement(_this.error, definition_1.FieldClassesEnum.FIELD_ERROR_MESSAGE); }),
            this.attachmentElement,
            util_1.ConditionUtils.orNull(this.isKeyboardUsed && this.isKeyboardOpen(), function () { return _this.keyboardElement; })));
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        // Need to invoke a user validator if it exists (After F5, etc...)
        this.validateValueAndSetCustomValidity(this.value);
        var autoFocus = this.originalProps.autoFocus;
        if (autoFocus) {
            this.setFocus();
        }
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this.onCloseVirtualKeyboard();
    };
    /**
     * @stable [21.06.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    Field.prototype.componentDidUpdate = function (prevProps, prevState) {
        var useKeyboard = prevProps.useKeyboard, value = prevProps.value;
        if (this.isKeyboardUsed) {
            if (this.isKeyboardOpen()
                && !R.equals(this.originalProps.value, value)) {
                this.refreshCaretPosition();
            }
        }
        else if (useKeyboard) { // Previous props
            this.closeVirtualKeyboard();
        }
        _super.prototype.componentDidUpdate.call(this, prevProps, prevState);
    };
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     */
    Field.prototype.onChange = function (event) {
        this.onChangeValue(this.getRawValueFromEvent(event));
    };
    /**
     * @stable [21.06.2020]
     * @param {TValue} currentRawValue
     */
    Field.prototype.onChangeManually = function (currentRawValue) {
        if (!this.areManualChangesNotPrevented) {
            return;
        }
        util_1.ConditionUtils.ifNotNilThanValue(this.input, function (input) {
            // We should update the field manually before calls the HTML5 validation
            input.value = String(currentRawValue);
        });
        this.onChangeValue(currentRawValue);
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.setFocus = function () {
        var _this = this;
        util_1.ConditionUtils.ifNotNilThanValue(this.input, function (input) {
            if (!_this.isFocusPrevented) {
                input.focus();
            }
        });
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.clearValue = function () {
        this.setFocus();
        if (this.isValuePresent) {
            this.onChangeManually(this.emptyValue);
        }
        util_1.ConditionUtils.ifNotNilThanValue(this.originalProps.onClear, function (onClear) { return onClear(); });
    };
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     * @returns {AnyT}
     */
    Field.prototype.getRawValueFromEvent = function (event) {
        return event.target.value;
    };
    Object.defineProperty(Field.prototype, "value", {
        /**
         * @stable [17.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            var value = this.originalProps.value;
            return this.isValueDefined(value) ? value : this.defaultValue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "input", {
        /**
         * @stable [03.06.2020]
         * @returns {InputElementT}
         */
        get: function () {
            return util_1.ConditionUtils.ifNotNilThanValue(this.inputRef.current, function (input) { return input.inputElement || input; });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [05.06.2020]
     */
    Field.prototype.removeFocus = function () {
        if (this.hasInput) {
            this.input.blur();
        }
    };
    Object.defineProperty(Field.prototype, "displayValueElement", {
        get: function () {
            return null; // TODO
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "keyboardElement", {
        get: function () {
            return (React.createElement(keyboard_component_1.Keyboard, __assign({ forwardedRef: this.keyboardRef, field: this, onClose: this.closeVirtualKeyboard, onChange: this.onKeyboardChange }, this.getKeyboardProps())));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [21.06.2020]
     * @param {IFocusEvent} event
     */
    Field.prototype.onFocus = function (event) {
        var _this = this;
        if (this.isFocusPrevented || this.isKeyboardUsed) {
            this.removeFocus(); // Prevent native keyboard opening during use of a synthetic keyboard
            if (this.isKeyboardUsed) {
                this.openVirtualKeyboard();
            }
        }
        else {
            this.setState({ focused: true }, function () { return util_1.ConditionUtils.ifNotNilThanValue(_this.originalProps.onFocus, function (onFocus) { return onFocus(event); }); });
        }
    };
    Field.prototype.openVirtualKeyboard = function () {
        var _this = this;
        if (this.isKeyboardOpen()) {
            return;
        }
        this.setState({ keyboardOpen: true }, function () {
            if (!_this.isInlineKeyboard) {
                _this.keyboardListenerUnsubscriber = _this.domAccessor.captureEvent({
                    element: _this.environment.document,
                    callback: _this.onDocumentClickHandler,
                    capture: true,
                    eventName: _this.environment.touchedPlatform ? definition_1.TouchEventsEnum.TOUCH_START : definition_1.EventsEnum.MOUSE_DOWN,
                });
            }
            if (util_1.isDef(_this.caretBlinkingTask)) {
                _this.caretBlinkingTask.start();
                // Need to refresh a caret position right after keyboard opening
                _this.refreshCaretPosition();
            }
        });
    };
    /**
     * @stable [17.06.2020]
     * @param {IBaseEvent} event
     */
    Field.prototype.onClick = function (event) {
        this.domAccessor.cancelEvent(event);
        util_1.ConditionUtils.ifNotNilThanValue(this.originalProps.onClick, function (onClick) { return onClick(event); });
    };
    /**
     * @stable [03.06.2020]
     * @param {AnyT} currentRawValue
     */
    Field.prototype.onChangeValue = function (currentRawValue) {
        var originalProps = this.originalProps;
        var _a = this.originalProps, name = _a.name, onChange = _a.onChange, onFormChange = _a.onFormChange;
        var actualFieldValue = util_1.FieldUtils.asActualFieldValue(__assign({}, originalProps, { emptyValue: this.emptyValue, value: currentRawValue }));
        this.validateField(actualFieldValue);
        util_1.ConditionUtils.ifNotNilThanValue(onChange, function () { return onChange(actualFieldValue); });
        util_1.ConditionUtils.ifNotNilThanValue(onFormChange, function () { return onFormChange(name, actualFieldValue); });
    };
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @param {boolean} forceApplyValue
     * @returns {AnyT}
     */
    Field.prototype.getDecoratedDisplayValue = function (value, forceApplyValue) {
        if (forceApplyValue === void 0) { forceApplyValue = false; }
        var displayValue = this.originalProps.displayValue;
        return R.isNil(displayValue)
            ? this.decorateDisplayValue(value)
            : (util_1.TypeUtils.isFn(displayValue)
                ? util_1.CalcUtils.calc(displayValue, this.decorateDisplayValue(value))
                : this.decorateDisplayValue(forceApplyValue ? value : displayValue));
    };
    Object.defineProperty(Field.prototype, "decoratedDisplayValue", {
        /**
         * @stable [17.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            return this.getDecoratedDisplayValue(this.value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    Field.prototype.decorateDisplayValue = function (value) {
        return value;
    };
    /**
     * @stable [18.05.2020]
     * @returns {FieldComposedInputAttributesT}
     */
    Field.prototype.getInputElementProps = function () {
        return {}; // TODO
    };
    Object.defineProperty(Field.prototype, "selfElement", {
        /**
         * @stable [19.06.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var style = this.originalProps.style;
            if (this.isFieldRendered) {
                return (React.createElement("div", { ref: this.actualRef, style: style, title: this.title, className: definition_1.FieldClassesEnum.FIELD_SELF },
                    this.prefixLabelElement,
                    this.inputWrapperElement,
                    this.actionsElement,
                    this.labelElement,
                    this.progressInfoElement));
            }
            return this.inputWrapperElement;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "actionsElement", {
        /**
         * @stable [22.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "inputWrapperElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            if (this.isFieldRendered) {
                return (React.createElement("div", { className: definition_1.FieldClassesEnum.FIELD_INPUT_WRAPPER },
                    this.getInputElement(),
                    this.mirrorInputElement,
                    this.inputCaretElement,
                    this.inputAttachmentElement));
            }
            return this.inputAttachmentElement;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    Field.prototype.getInputElement = function () {
        return React.createElement("input", __assign({}, this.getInputElementProps()));
    };
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    Field.prototype.getFieldClassName = function () {
        var originalProps = this.originalProps;
        var className = originalProps.className, label = originalProps.label;
        return util_1.ClsUtils.joinClassName(definition_1.FieldClassesEnum.FIELD, label && definition_1.FieldClassesEnum.FIELD_LABELED, this.isBusy && definition_1.FieldClassesEnum.FIELD_BUSY, this.isChangeable ? definition_1.FieldClassesEnum.FIELD_CHANGEABLE : definition_1.FieldClassesEnum.FIELD_NOT_CHANGEABLE, this.isDisabled && definition_1.FieldClassesEnum.FIELD_DISABLED, this.isFocused ? definition_1.FieldClassesEnum.FIELD_FOCUSED : definition_1.FieldClassesEnum.FIELD_NOT_FOCUSED, this.isInvalid && definition_1.FieldClassesEnum.FIELD_INVALID, this.isRequired && definition_1.FieldClassesEnum.FIELD_REQUIRED, this.isValuePresent ? definition_1.FieldClassesEnum.FIELD_VALUE_PRESENT : definition_1.FieldClassesEnum.FIELD_VALUE_NOT_PRESENT, util_1.CalcUtils.calc(className));
    };
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    Field.prototype.getLabel = function () {
        return this.originalProps.label;
    };
    /**
     * @stable [22.06.2020]
     * @returns {Array<string | RegExp>}
     */
    Field.prototype.getFieldMask = function () {
        return this.originalProps.mask;
    };
    /**
     * @stable [21.06.2020]
     * @returns {IKeyboardProps}
     */
    Field.prototype.getKeyboardProps = function () {
        return this.mergedProps.keyboardConfiguration || {};
    };
    /**
     * @stable [10.08.2020]
     * @protected
     */
    Field.prototype.getComponentsSettingsProps = function () {
        return this.componentsSettings.field;
    };
    Object.defineProperty(Field.prototype, "inputAttachmentElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "attachmentElement", {
        /**
         * @stable [16.06.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "mirrorInputElement", {
        /**
         * @stable [18.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "progressInfoElement", {
        /**
         * @stable [19.05.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return util_1.ConditionUtils.orNull(this.isBusy, function () { return React.createElement(info_component_1.Info, { progress: true }); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isCursorUsed", {
        // TODO
        get: function () {
            return util_1.WrapperUtils.isCursorUsed(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isKeyboardAndCursorUsed", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.isKeyboardUsed && this.isCursorUsed;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "emptyValue", {
        /**
         * @stable [19.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            var emptyValue = this.originalProps.emptyValue;
            return util_1.TypeUtils.isDef(emptyValue) ? emptyValue : this.originalEmptyValue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "originalEmptyValue", {
        /**
         * @stable [19.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            return definition_1.FieldConstants.DISPLAY_EMPTY_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "defaultValue", {
        /**
         * @stable [19.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            return this.originalProps.defaultValue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "displayValue", {
        /**
         * @stable [19.06.2020]
         * @returns {AnyT}
         */
        get: function () {
            return !this.isValuePresent || (this.isFocusPrevented && this.isBusy)
                ? definition_1.FieldConstants.DISPLAY_EMPTY_VALUE
                : this.decoratedDisplayValue;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    Field.prototype.isKeyboardOpen = function () {
        return this.state.keyboardOpen || this.isInlineKeyboard;
    };
    /**
     * @stable [19.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    Field.prototype.isValueObject = function (value) {
        return util_1.TypeUtils.isObject(value);
    };
    Object.defineProperty(Field.prototype, "isPlainValueApplied", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isPlainValueApplied(this.mergedProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isValuePresent", {
        /**
         * @stable [20.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.ValueUtils.isValuePresent(this.value, this.emptyValue);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isKeyboardUsed", {
        /**
         * @stable [20.06.2020]
         * @returns {boolean | undefined}
         */
        get: function () {
            return this.originalProps.useKeyboard;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isRequired", {
        /**
         * @stable [20.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.originalProps.required;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isDisabled", {
        /**
         * @stable [20.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.originalProps.disabled;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isValueNotPresent", {
        /**
         * @stable [20.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return !this.isValuePresent;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [03.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    Field.prototype.isValueDefined = function (value) {
        return util_1.TypeUtils.isDef(value);
    };
    Object.defineProperty(Field.prototype, "isInputValid", {
        /**
         * @stable [03.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return !this.hasInput || this.input.validity.valid;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isFocusPrevented", {
        /**
         * @stable [03.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isFocusPrevented(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isBusy", {
        /**
         * @stable [05.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.inProgress(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isFieldRendered", {
        /**
         * @stable [03.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isFieldRendered(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isReadOnly", {
        /**
         * @stable [02.08.2020]
         */
        get: function () {
            return util_1.FieldUtils.isFieldReadOnly(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isInactive", {
        /**
         * @stable [02.08.2020]
         */
        get: function () {
            return util_1.FieldUtils.isFieldInactive(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isActive", {
        /**
         * @stable [02.08.2020]
         */
        get: function () {
            return !this.isInactive;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isDisplayValueDefined", {
        /**
         * @stable [22.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.TypeUtils.isDef(this.originalProps.displayValue);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "hasInput", {
        /**
         * @stable [03.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.inputRef.current);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "componentsSettingsProps", {
        /**
         * @stable [03.06.2020]
         * @returns {TProps}
         */
        get: function () {
            return this.getComponentsSettingsProps();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.refreshCaretPosition = function () {
        var _this = this;
        this.setState({ caretPosition: this.caretPosition }, function () { return _this.input.scrollLeft = _this.input.scrollWidth; });
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.setCaretVisibility = function () {
        var _this = this;
        this.setState(function (prevState) { return util_1.FilterUtils.notNilValuesFilter({
            caretVisibility: !prevState.caretVisibility,
            caretPosition: util_1.ConditionUtils.ifNilThanValue(prevState.caretPosition, function () { return _this.caretPosition; }),
        }); });
    };
    /**
     * @stable [21.06.2020]
     * @param {AnyT} rawValue
     */
    Field.prototype.validateField = function (rawValue) {
        this.setState({ error: this.validateValueAndSetCustomValidity(rawValue) });
    };
    /**
     * @stable [21.06.2020]
     * @param {AnyT} value
     * @returns {string}
     */
    Field.prototype.validateValueAndSetCustomValidity = function (value) {
        if (this.hasInput) {
            this.input.setCustomValidity('');
        }
        if (this.isInputValid) {
            return null;
        }
        return this.inputValidationMessage;
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.closeVirtualKeyboard = function () {
        this.setState({ keyboardOpen: false }, this.onCloseVirtualKeyboard);
    };
    /**
     * @stable [21.06.2020]
     * @param {IBaseEvent} event
     */
    Field.prototype.onDocumentClickHandler = function (event) {
        var keyboardEl = this.keyboardRef.current;
        if (!keyboardEl) {
            return;
        }
        var element = event.target;
        if (this.domAccessor.getParentsAsElements({ parentClassName: definition_1.KeyboardClassNamesEnum.KEYBOARD, element: element })
            .includes(keyboardEl)) {
            return;
        }
        this.closeVirtualKeyboard();
    };
    /**
     * @stable [21.06.2020]
     */
    Field.prototype.onCloseVirtualKeyboard = function () {
        var _this = this;
        util_1.ConditionUtils.ifNotNilThanValue(this.caretBlinkingTask, function (caretBlinkingTask) { return caretBlinkingTask.stop(); });
        util_1.ConditionUtils.ifNotNilThanValue(this.keyboardListenerUnsubscriber, function () {
            _this.keyboardListenerUnsubscriber();
            _this.keyboardListenerUnsubscriber = null;
        });
    };
    /**
     * @stable [21.06.2020]
     * @param {string} rawValue
     */
    Field.prototype.onKeyboardChange = function (rawValue) {
        // Synthetic event creation to reduce source code
        var syntheticEvent = { target: { value: rawValue } };
        // To handle the various field types, NumberField, etc..
        this.onChangeManually(this.getRawValueFromEvent(syntheticEvent));
    };
    /**
     * @stable [21.06.2020]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    Field.prototype.messageElement = function (message, className) {
        return (React.createElement("div", { title: message, className: util_1.ClsUtils.joinClassName(definition_1.FieldClassesEnum.FIELD_MESSAGE, className) }, message ? this.t(message) : definitions_interface_1.UniCodesEnum.NO_BREAK_SPACE));
    };
    Object.defineProperty(Field.prototype, "labelElement", {
        /**
         * @stable [21.06.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return util_1.ConditionUtils.ifNotNilThanValue(this.getLabel(), function (label) { return (React.createElement("label", { className: definition_1.FieldClassesEnum.FIELD_LABEL }, _this.t(label))); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "prefixLabelElement", {
        /**
         * @stable [21.06.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var prefixLabel = this.originalProps.prefixLabel;
            return (util_1.ConditionUtils.ifNotNilThanValue(prefixLabel, function () { return (React.createElement("span", { className: definition_1.FieldClassesEnum.FIELD_PREFIX_LABEL }, prefixLabel)); }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "inputCaretElement", {
        /**
         * @stable [21.06.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var _a = this.state, caretPosition = _a.caretPosition, caretVisibility = _a.caretVisibility;
            return util_1.ConditionUtils.ifNotNilThanValue(caretPosition, function () { return util_1.ConditionUtils.orNull(_this.isCursorUsed && _this.isKeyboardOpen() && caretVisibility, function () {
                var textOffset = 2;
                var paddingLeft = parseFloat(_this.domAccessor.getProperty(_this.input, 'paddingLeft'));
                var left = caretPosition + paddingLeft - textOffset;
                return (React.createElement("div", { className: definition_1.FieldClassesEnum.FIELD_INPUT_CARET, style: { left: left } }, "|"));
            }); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "title", {
        /**
         * @stable [21.06.2020]
         * @returns {string}
         */
        get: function () {
            var _this = this;
            var title = this.originalProps.title;
            return title || util_1.ConditionUtils.orNull(this.isFocusPrevented, function () { return _this.displayValue; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "caretPosition", {
        /**
         * @stable [21.06.2020]
         * @returns {number}
         */
        get: function () {
            return this.isValuePresent
                ? Math.min(this.domAccessor.getWidth(this.inputMirrorRef.current), this.domAccessor.getWidth(this.input))
                : 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isErrorMessageRendered", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isErrorMessageRendered(this.mergedProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "areManualChangesNotPrevented", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.areManualChangesNotPrevented(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isChangeable", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isChangeable(this.originalProps);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isInvalid", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return !util_1.WrapperUtils.isValid(this.originalProps) || !R.isNil(this.error);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isFocused", {
        /**
         * @stable [22.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.isKeyboardUsed
                ? this.isKeyboardOpen()
                : this.state.focused;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "isInlineKeyboard", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.WrapperUtils.isInline(this.getKeyboardProps());
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "inputValidationMessage", {
        /**
         * @stable [21.06.2020]
         * @returns {string}
         */
        get: function () {
            return this.input.validationMessage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Field.prototype, "error", {
        /**
         * @stable [21.06.2020]
         * @returns {string}
         */
        get: function () {
            return this.state.error;
        },
        enumerable: true,
        configurable: true
    });
    return Field;
}(enhanced_generic_component_1.EnhancedGenericComponent));
exports.Field = Field;
//# sourceMappingURL=field.component.js.map