import { IEntity, IKeyValue } from '../../../definitions.interface';
import { IMultiFieldChangesEntity } from './multifield.interface';
import { IReduxMultiEntity, IMultiItemEntity, MultiFieldEntityT, MultiFieldSingleValueT } from '../../../definition';
/**
 * @stable [29.07.2019]
 * @param {MultiFieldSingleValueT} multiFieldEntity
 * @returns {EntityIdT}
 */
export declare const toLastAddedMultiItemEntityId: (multiFieldEntity: MultiFieldSingleValueT) => string | number;
/**
 * @stable [04.07.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @returns {EntityIdT[]}
 */
export declare const fromMultiFieldEntityToEditedEntitiesIds: (multiFieldEntity: MultiFieldEntityT<IEntity>) => (string | number)[];
/**
 * @stable [18.08.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare function fromMultiFieldEntityToEditedEntities<TItem extends IEntity = IEntity, TResult = IEntity>(multiFieldEntity: MultiFieldEntityT<TItem>, mapper: (entity: TItem, index: number) => TResult): TResult[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {(value: IMultiEntity) => IMultiItemEntity[]} converter
 * @param {IEntity[]} defaultValue
 * @returns {IMultiItemEntity[] | IEntity[]}
 */
export declare const extractMultiItemEntities: (value: MultiFieldEntityT<IEntity>, converter: (value: IReduxMultiEntity<IEntity>) => IMultiItemEntity[], defaultValue: IEntity[]) => IEntity[] | IMultiItemEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
export declare const extractMultiEditItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IMultiItemEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
export declare const extractMultiRemoveItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IMultiItemEntity[];
/**
 * @stable [02.07.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiAddItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiSourceItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IEntity[]) => IEntity[];
/**
 * @stable [02.07.2018]
 * @param {IEntity | IMultiItemEntity} entity
 * @returns {IEntity}
 */
export declare const fromMultiItemEntityToEntity: (entity: IEntity | IMultiItemEntity) => IEntity;
/**
 * @stable [23.06.2018]
 * @param {string} fieldName
 * @param {MultiFieldEntityT} multiFieldValue
 * @param {(itm: IMultiItemEntity) => boolean} predicate
 * @param {(itm: IMultiItemEntity) => AnyT} nextFieldValueFn
 * @returns {IMultiItemEntity}
 */
export declare const buildMultiEditItemEntityPayload: <TEntity extends IEntity = IEntity>(fieldName: string, multiFieldValue: MultiFieldEntityT<IEntity>, predicate: (itm: IMultiItemEntity) => boolean, nextFieldValueFn: (multiItemEntity: IMultiItemEntity, entity: TEntity) => any) => IMultiItemEntity;
/**
 * @stable [04.07.2018]
 * @param {IMultiItemEntity[]} multiItemEntities
 * @returns {IKeyValue}
 */
export declare const fromMultiItemEntitiesToFieldsChanges: (multiItemEntities: IMultiItemEntity[]) => IKeyValue;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} first
 * @param {IMultiItemEntity} second
 * @returns {boolean}
 */
export declare const isSameEntityByIdAndChangedFieldName: (first: IMultiItemEntity, second: IMultiItemEntity) => boolean;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnEdit: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
/**
 * @stable [18.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnDelete: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
/**
 * @stable [07.03.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity>} multiEntity
 * @param {MultiFieldEntityT<TEntity extends IEntity>} updatedSource
 * @param {(entity: TEntity) => boolean} addFilter
 * @param {(entity: TEntity) => boolean} editFilter
 * @param {(entity: TEntity) => boolean} removeFilter
 * @returns {IReduxMultiEntity}
 */
export declare const toFilteredMultiEntity: <TEntity extends IEntity>(multiEntity: MultiFieldEntityT<TEntity>, updatedSource: MultiFieldEntityT<TEntity>, addFilter?: (entity: TEntity) => boolean, editFilter?: (entity: TEntity) => boolean, removeFilter?: (entity: TEntity) => boolean) => IReduxMultiEntity<IEntity>;
