"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var react_text_mask_1 = require("react-text-mask");
var util_1 = require("../../../util");
var definitions_interface_1 = require("../../../definitions.interface");
var field_1 = require("../field");
var definition_1 = require("../../../definition");
var BaseTextField = /** @class */ (function (_super) {
    __extends(BaseTextField, _super);
    /**
     * @stable [17.06.2020]
     * @param {TProps} originalProps
     */
    function BaseTextField(originalProps) {
        var _this = _super.call(this, originalProps) || this;
        _this.defaultActions = [];
        if (util_1.WrapperUtils.isClearActionRendered(_this.originalProps)) {
            _this.addClearAction();
        }
        return _this;
    }
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    BaseTextField.prototype.getInputElement = function () {
        return R.isNil(this.getFieldMask())
            ? _super.prototype.getInputElement.call(this)
            : this.getMaskedInputElement();
    };
    /**
     * @stable [18.06.2020]
     * @returns {string}
     */
    BaseTextField.prototype.getFieldClassName = function () {
        var prefixLabel = this.originalProps.prefixLabel;
        return util_1.ClsUtils.joinClassName(_super.prototype.getFieldClassName.call(this), definition_1.TextFieldClassesEnum.BASE_TEXT_FIELD, this.isActioned && definition_1.TextFieldClassesEnum.BASE_TEXT_FIELD_ACTIONED, prefixLabel
            ? definition_1.TextFieldClassesEnum.BASE_TEXT_FIELD_LABEL_PREFIXED
            : definition_1.TextFieldClassesEnum.BASE_TEXT_FIELD_LABEL_NOT_PREFIXED);
    };
    Object.defineProperty(BaseTextField.prototype, "mirrorInputElement", {
        /**
         * @stable [12.09.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            if (!this.isKeyboardAndCursorUsed || this.isValueNotPresent) {
                return null;
            }
            // TODO Move to support
            var value = this.value;
            var content = String((this.props.type === 'password'
                ? String(value).replace(/./g, this.environment.passwordPlaceholder)
                : value)).replace(/ /g, definitions_interface_1.UniCodesEnum.NO_BREAK_SPACE);
            return (React.createElement("span", { ref: this.inputMirrorRef, className: util_1.ClsUtils.joinClassName(this.getInputElementProps().className, definition_1.FieldClassesEnum.FIELD_INPUT_MIRROR, definition_1.ComponentClassesEnum.INVISIBLE) }, content));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [28.10.2019]
     * @param {} action
     * @returns {boolean}
     */
    BaseTextField.prototype.isFieldActionDisabled = function (action) {
        return util_1.CalcUtils.calc(action.disabled) || this.isInactive;
    };
    /**
     * @stable [25.02.2019]
     * @returns {JSX.Element}
     */
    BaseTextField.prototype.getMaskedInputElement = function () {
        var mask = this.getFieldMask();
        var props = this.props;
        return (React.createElement(react_text_mask_1.default, __assign({ guide: util_1.nvl(props.maskGuide, BaseTextField.DEFAULT_MASK_GUIDE), placeholderChar: util_1.nvl(props.maskPlaceholderChar, definitions_interface_1.UniCodesEnum.SPACE), mask: mask }, this.getInputElementProps())));
    };
    Object.defineProperty(BaseTextField.prototype, "actionsElement", {
        /**
         * @stable [18.04.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return (React.createElement(React.Fragment, null, this.fieldActions.map(function (action, index) { return (React.createElement(React.Fragment, { key: "field-action-key-" + index }, _this.uiFactory.makeIcon(__assign({}, action, { disabled: _this.isFieldActionDisabled(action) })))); })));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [30.10.2019]
     */
    BaseTextField.prototype.addClearAction = function () {
        var _this = this;
        this.defaultActions.push({
            type: definition_1.FieldActionTypesEnum.CLOSE,
            onClick: function () { return _this.clearValue(); },
            disabled: function () { return _this.isInactive; },
        });
    };
    Object.defineProperty(BaseTextField.prototype, "fieldActions", {
        /**
         * @stable [17.06.2020]
         * @returns {IFieldActionEntity[]}
         */
        get: function () {
            var _this = this;
            if (this.isReadOnly) {
                return [];
            }
            var originalProps = this.originalProps;
            var _a = originalProps.actions, actions = _a === void 0 ? [] : _a, actionsPosition = originalProps.actionsPosition;
            var defaultActions = this.defaultActions || [];
            var fieldActions = actionsPosition === definition_1.FieldActionPositionsEnum.LEFT
                ? defaultActions.concat(actions)
                : actions.concat(defaultActions);
            return fieldActions.filter(function (action) {
                switch (action.type) {
                    case definition_1.FieldActionTypesEnum.CLOSE:
                        return _this.isValuePresent;
                }
                return true;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseTextField.prototype, "isActioned", {
        /**
         * @stable [21.06.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.ObjectUtils.isObjectNotEmpty(this.fieldActions);
        },
        enumerable: true,
        configurable: true
    });
    BaseTextField.DEFAULT_MASK_GUIDE = false;
    return BaseTextField;
}(field_1.Field2));
exports.BaseTextField = BaseTextField;
//# sourceMappingURL=base-text-field.component.js.map