"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var util_1 = require("../../../util");
var generic_pdf_plugin_1 = require("./generic-pdf.plugin");
var viewer_component_1 = require("../viewer.component");
var PdfViewer = /** @class */ (function (_super) {
    __extends(PdfViewer, _super);
    /**
     * @stable [16.03.2020]
     * @param {IPdfViewerProps} props
     */
    function PdfViewer(props) {
        var _this = _super.call(this, props) || this;
        _this.canvasRef = React.createRef();
        _this.pdfRendererPlugin =
            new generic_pdf_plugin_1.GenericPdfPlugin(_this.settings.urls.pdfWorker + "?_dc=" + _this.environment.appVersion, function () { return _this.canvasRef.current; }, _this.onLoadSucceed)
                .setAutoScale(true)
                .setOnStart(_this.onLoadStart)
                .setOnError(_this.onLoadError);
        return _this;
    }
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.componentWillUnmount = function () {
        this.pdfRendererPlugin.cancel();
        this.pdfRendererPlugin = null;
    };
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.refreshOnSrcChanges = function () {
        var _this = this;
        util_1.ConditionUtils.ifNotNilThanValue(this.actualSrc, function (src) {
            // This plugin can't process the null value
            _this.pdfRendererPlugin
                .setSrc(src)
                .setPage(_this.actualOrDefaultPage)
                .setScale(_this.actualOrDefaultScale)
                .loadDocument();
        });
    };
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.refreshOnInternalChanges = function () {
        this.pdfRendererPlugin
            .setPage(this.actualOrDefaultPage)
            .setScale(this.actualOrDefaultScale)
            .refreshPage();
    };
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.getContentElement = function () {
        return React.createElement("canvas", { ref: this.canvasRef });
    };
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.gePreviewElement = function () {
        return (React.createElement(PdfViewer, { usePreview: false, src: this.actualSrc, page: this.actualOrDefaultPreviewPage, scale: this.actualOrDefaultPreviewScale }));
    };
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    PdfViewer.prototype.isPreviewForwardActionDisabled = function () {
        return this.actualOrDefaultPreviewPage === this.pdfRendererPlugin.pagesCount;
    };
    Object.defineProperty(PdfViewer.prototype, "defaultScale", {
        /**
         * @stable [23.03.2020]
         * @returns {number}
         */
        get: function () {
            return 0; // Because of "autoscale = true" by default
        },
        enumerable: true,
        configurable: true
    });
    return PdfViewer;
}(viewer_component_1.Viewer));
exports.PdfViewer = PdfViewer;
//# sourceMappingURL=pdf-viewer.component.js.map