import { INumberConverter } from './number-converter.interface';
import { EntityIdT, StringNumberT } from '../../definitions.interface';
export declare class NumberConverter implements INumberConverter {
    private settings;
    private defaultFormatter;
    /**
     * @stable [22.10.2018]
     */
    private defaultCurrencyFormatOptions;
    private currencyFormatter;
    private defaultIntegerFormatOptions;
    private integerFormatter;
    private fractionalFormatter;
    /**
     * @stable [22.10.2018]
     */
    private defaultIntegerCurrencyFormatOptions;
    private integerCurrencyFormatter;
    /**
     * @stable [22.10.2018]
     */
    constructor();
    /**
     * @stable [25.12.2019]
     * @param {StringNumberT} value
     * @returns {number}
     */
    asNumber(value: StringNumberT): number;
    /**
     * @stable [28.09.2018]
     * @param {StringNumberT} value
     * @param {number} radix
     * @returns {StringNumberT}
     */
    integer(value: StringNumberT, radix?: number): StringNumberT;
    /**
     * @stable [19.12.2019]
     * @param {StringNumberT} value
     * @param {boolean} returnString
     * @returns {StringNumberT}
     */
    number(value: StringNumberT, returnString?: boolean): StringNumberT;
    /**
     * @stable [29.08.2019]
     * @param {StringNumberT} value
     * @param {(value: number) => number} converter
     * @returns {number}
     */
    numberParameter(value: StringNumberT, converter?: (value: number) => number): number;
    format(value: string | number, formatter?: {
        format(...args: any[]): string;
    }): string;
    integerCurrency(value: StringNumberT): string;
    /**
     * @stable [25.04.2020]
     * @param {StringNumberT} value
     * @returns {string}
     */
    integerFormat(value: StringNumberT): string;
    /**
     * @stable [25.04.2020]
     * @param {StringNumberT} value
     * @returns {string}
     */
    fractionalFormat(value: StringNumberT): string;
    currency(value: number | string, options?: Intl.NumberFormatOptions): string;
    /**
     * @stable [01.09.2018]
     * @param {EntityIdT} value
     * @returns {string}
     */
    id(value: EntityIdT): string;
    /**
     * @stable [01.09.2018]
     * @param {EntityIdT} value
     * @returns {string}
     */
    internalId(value: EntityIdT): string;
    /**
     * @stable [25.04.2020]
     * @param {StringNumberT} value
     * @param {Intl.NumberFormat} formatter
     * @returns {string}
     */
    private useFormatter;
    /**
     * @stable [22.10.2018]
     * @returns {string}
     */
    private readonly uiLocale;
}
