"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var action_builder_1 = require("../../component/action.builder");
var chained_middleware_1 = require("./chained.middleware");
var util_1 = require("../../util");
var default_form_changes_middleware_1 = require("./default-form-changes.middleware");
/**
 * @stable [03.04.2020]
 * @param {IEditedListMiddlewareConfigEntity<TPayload, TState, TDefaultChanges>} cfg
 * @returns {IChainedMiddlewareConfigEntity<TState, TPayload>}
 */
var asChainedConfigEntity = function (cfg) {
    return ({
        action: cfg.action,
        nextSection: util_1.toFormSection(cfg),
        path: cfg.path,
        state: cfg.state,
    });
};
/**
 * @stable [03.04.2020]
 * @param {IEditedListMiddlewareConfigEntity<TState, TDefaultChanges>} config
 * @returns {IEffectsAction[]}
 */
exports.makeCreateEntityMiddleware = function (config) {
    return util_1.ConditionUtils.ifNotNilThanValue(chained_middleware_1.makeChainedMiddleware(asChainedConfigEntity(config)), function (actions) { return util_1.FilterUtils.notNilValuesArrayFilter.apply(util_1.FilterUtils, actions.concat([default_form_changes_middleware_1.makeDefaultFormChangesMiddleware(config)])); });
};
/**
 * @stable [03.04.2020]
 * @param {IEditedListMiddlewareConfigEntity<TPayload, TState, TDefaultChanges>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeSelectEntityMiddleware = function (cfg) {
    var action = cfg.action;
    var selected = util_1.selectSelectedEntityFromAction(action);
    return cfg.lazyLoading
        ? [
            action_builder_1.ListActionBuilder.buildLazyLoadAction(util_1.toListSection(cfg), util_1.defValuesFilter({
                selected: selected,
                preventEffects: util_1.Selectors.preventEffectsFromAction(action),
                previousAction: util_1.Selectors.previousActionFromAction(action),
            }))
        ]
        : chained_middleware_1.makeChainedMiddleware(__assign({}, asChainedConfigEntity(cfg), { payload: selected }));
};
/**
 * @stable [03.04.2020]
 * @param {IEditedListMiddlewareConfigEntity<TPayload, TState, TDefaultChanges>} config
 * @returns {IEffectsAction[]}
 */
exports.makeLazyLoadedEntityMiddleware = function (config) {
    var action = config.action;
    var result = util_1.ConditionUtils.ifNotNilThanValue(util_1.Selectors.previousActionTypeFromAction(action), function (previousActionType) { return [redux_effects_promise_1.EffectsAction.create(redux_effects_promise_1.EffectsActionBuilder.buildDoneActionType(previousActionType))]; }, []).concat(chained_middleware_1.makeChainedMiddleware(__assign({}, asChainedConfigEntity(config), { payload: action.data })) || []);
    return util_1.ConditionUtils.orNull(util_1.ObjectUtils.isObjectNotEmpty(result), result);
};
//# sourceMappingURL=edited-list.middleware.js.map