"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var action_builder_1 = require("../../component/action.builder");
var util_1 = require("../../util");
var default_form_changes_middleware_1 = require("./default-form-changes.middleware");
/**
 * @stable [29.03.2020]
 * @param {ILoadedListMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction}
 */
exports.makeLoadedListMiddleware = function (cfg) {
    return action_builder_1.ListActionBuilder.buildLoadAction(util_1.toListSection(cfg));
};
/**
 * @stable [29.03.2020]
 * @param {ILoadedListOnFormValidMiddlewareConfigEntity<TState>} config
 * @returns {IEffectsAction}
 */
exports.makeLoadedListOnFormValidMiddleware = function (config) {
    return util_1.ConditionUtils.orNull(util_1.ValueUtils.isValueValid(util_1.selectValidFromAction(config.action)), function () { return exports.makeLoadedListMiddleware(config); });
};
/**
 * @stable [29.03.2020]
 * @param {ILoadedListOnTabActivateMiddlewareConfigEntity<TState>} config
 * @returns {IEffectsAction}
 */
exports.makeLoadedListOnTabActivateMiddleware = function (config) {
    return exports.makeLoadedListMiddleware(config);
};
/**
 * @stable [11.04.2020]
 * @param {ILoadedListOnToolbarToolsRefreshConfigEntity<TState>} config
 * @returns {IEffectsAction}
 */
exports.makeLoadedListOnToolbarToolsRefreshMiddleware = function (config) {
    return exports.makeLoadedListMiddleware(config);
};
/**
 * @stable [29.03.2020]
 * @param {IUntouchedListMiddlewareConfigEntity<TState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeUntouchedListMiddleware = function (config) {
    return util_1.ConditionUtils.ifNotEmptyThanValue(util_1.FilterUtils.notNilValuesArrayFilter(default_form_changes_middleware_1.makeDefaultFormChangesMiddleware(config), util_1.ConditionUtils.orNull(!util_1.WrapperUtils.isTouched(config.listAccessor(config.state)), function () { return exports.makeLoadedListMiddleware(config); })), function (actions) { return actions; });
};
/**
 * @stable [15.06.2020]
 * @param {ILoadedListOnNavigateToPageMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeLoadedListOnNavigateToPreviousPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildPreviousPageAction(util_1.toListSection(cfg)),
        exports.makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [15.06.2020]
 * @param {ILoadedListOnNavigateToPageMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeLoadedListOnNavigateToNextPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildNextPageAction(util_1.toListSection(cfg)),
        exports.makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [15.06.2020]
 * @param {ILoadedListOnNavigateToPageMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeLoadedListOnNavigateToFirstPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildFirstPageAction(util_1.toListSection(cfg)),
        exports.makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [15.06.2020]
 * @param {ILoadedListOnNavigateToPageMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeLoadedListOnNavigateToLastPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildLastPageAction(util_1.toListSection(cfg)),
        exports.makeLoadedListMiddleware(cfg)
    ];
};
//# sourceMappingURL=loaded-list.middleware.js.map