"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../util");
var action_1 = require("../../action");
var action_builder_1 = require("../../component/action.builder");
var di_1 = require("../../di");
/**
 * @stable [11.04.2020]
 * @param {ISucceedFormMiddlewareConfigEntity} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedFormMiddleware = function (cfg) {
    cfg = cfg || {};
    var succeedText = cfg.succeedText;
    var actualFormSection = util_1.toFormSection(cfg);
    return (util_1.isNavigateBackNeeded(cfg) || !util_1.isObjectNotEmpty(actualFormSection)
        ? [action_1.RouterActionBuilder.buildBackAction()]
        : [action_1.FormActionBuilder.buildSubmitDoneAction(actualFormSection)]).concat((succeedText === false
        ? []
        : [
            action_1.NotificationActionBuilder.buildInfoAction(di_1.getTranslator()(succeedText || di_1.getSettings().messages.DATA_HAS_BEEN_SUCCESSFULLY_SAVED))
        ]));
};
/**
 * @deprecated Use makeSucceedRelatedFormEntityMiddleware
 */
exports.makeSucceedRelatedFormMiddleware = function (config) {
    var formSection = config.formSection;
    var apiEntity = config.action.data;
    var parentEntity = config.getEntity(config.state);
    var relatedEntities = apiEntity.newEntity
        ? (config.getRelatedEntities(parentEntity) || []).concat(config.relatedEntity)
        : (config.getRelatedEntities(parentEntity) || []).map(function (anotherEntity) { return anotherEntity.id === config.relatedEntity.id ? config.relatedEntity : anotherEntity; });
    var changes = config.makeRelatedChanges(relatedEntities);
    var payloadWrapper = { payload: { id: parentEntity.id, changes: changes } };
    return util_1.ifNotNilThanValue(config.listSection, function (listSection) { return ([
        action_builder_1.ListActionBuilder.buildUpdateAction(listSection, payloadWrapper),
        config.navigateBack !== false
            ? action_1.RouterActionBuilder.buildBackAction()
            : action_1.FormActionBuilder.buildSubmitDoneAction(formSection)
    ]); }, []).concat([
        action_1.NotificationActionBuilder.buildInfoAction(di_1.getTranslator()(config.succeedText || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved))
    ]);
};
/**
 * @stable [11.04.2020]
 * @param {ISucceedEditedListMiddlewareConfigEntity<TState>} cfg
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedEditedListMiddleware = function (cfg) {
    var action = cfg.action, succeedText = cfg.succeedText;
    var actualListSection = util_1.toListSection(cfg);
    return [
        action_builder_1.ListActionBuilder.buildMergeAction(actualListSection, di_1.getModifyEntityPayloadFactory().makeInstance(action))
    ].concat((util_1.isNavigateBackNeeded(cfg)
        ? [
            action_1.RouterActionBuilder.buildReplaceAction(util_1.getRoutePath(di_1.getDynamicSections().get(util_1.nvl(util_1.toContainerSection(cfg), actualListSection))))
        ]
        : []), (succeedText === false
        ? []
        : [
            action_1.NotificationActionBuilder.buildInfoAction(di_1.getTranslator()(succeedText || di_1.getSettings().messages.DATA_HAS_BEEN_SUCCESSFULLY_SAVED))
        ]));
};
//# sourceMappingURL=succeed-form.middleware.js.map