"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var redux_1 = require("redux");
var redux_effects_promise_1 = require("redux-effects-promise");
var R = require("ramda");
var util_1 = require("../util");
/**
 * @stable - 10.04.2018
 * @param {string} customSection
 * @returns {FilterT}
 */
function reducerSectionFilter(customSection) {
    var section;
    return function (action) { return (!(section = util_1.toSection(action)) || customSection === section); };
}
exports.reducerSectionFilter = reducerSectionFilter;
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {FilterT} filterObject
 * @returns {Reducer<S>}
 */
exports.filter = function (reducer, filterObject) {
    return function (state, action) { return (filterObject(action) ? reducer(state, action) : state); };
};
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {string} customSection
 * @returns {Reducer<S>}
 */
exports.filterBySection = function (reducer, customSection) {
    return exports.filter(reducer, reducerSectionFilter(customSection));
};
/**
 * @stable - 15.04.2018
 * @param {TReducersMap} reducersMap
 * @returns {Reducer<ReducersMapObject>}
 */
exports.composeReducers = function (reducersMap) {
    return redux_1.combineReducers(reducersMap);
};
/**
 * @deprecated Use makeEntityReducer
 * @param {string} updateActionType
 * @param {string} destroyActionType
 * @param {TPayload} initialState
 * @returns {(state: TPayload, action: AnyAction) => TPayload}
 */
exports.entityReducerFactory = function (updateActionType, destroyActionType, initialState) {
    if (initialState === void 0) { initialState = null; }
    return function (state, action) {
        if (state === void 0) { state = initialState; }
        switch (action.type) {
            case updateActionType:
                var payloadWrapper = action.data;
                var selectedWrapper = action.data;
                var replacedWrapper = action.data;
                var entity = util_1.coalesce(payloadWrapper.payload, selectedWrapper.selected, replacedWrapper.replaced);
                // selected === null or payload === null
                var defEntity = util_1.coalesceDef(payloadWrapper.payload, selectedWrapper.selected, replacedWrapper.replaced);
                return R.isNil(entity)
                    ? (util_1.isUndef(defEntity) ? state : defEntity)
                    : (util_1.isPrimitive(entity)
                        ? entity
                        : (Array.isArray(entity)
                            ? entity.slice() : (R.isNil(replacedWrapper.replaced)
                            ? __assign({}, state, entity) : util_1.shallowClone(entity))));
            case destroyActionType:
                return null;
        }
        return state;
    };
};
/**
 * @stable [06.04.2020]
 * @param {IEntityReducerFactoryConfigEntity} config
 * @returns {(state: {}, action: AnyAction) => {}}
 */
exports.makeEntityReducer = function (config) {
    return function (state, action) {
        if (state === void 0) { state = config.initialState || null; }
        switch (action.type) {
            case config.update:
            case config.replace:
            case config.select:
                var selectedWrapper = action.data;
                var updatedWrapper = action.data;
                var replacedWrapper = action.data;
                var selectedEntity = selectedWrapper.selected;
                var updatedEntity = updatedWrapper.updated;
                var replacedEntity = replacedWrapper.replaced;
                var entity = util_1.coalesce(selectedEntity, updatedEntity, replacedEntity);
                // When selected === null or replaced === null or updated === null
                var defEntity = util_1.coalesceDef(selectedEntity, updatedEntity, replacedEntity);
                return R.isNil(entity)
                    ? (util_1.isUndef(defEntity) ? state : defEntity)
                    : (util_1.isPrimitive(entity)
                        ? entity
                        : (Array.isArray(entity)
                            ? entity.slice() : (R.isNil(replacedEntity)
                            ? __assign({}, state, entity) : util_1.shallowClone(entity) // Replace
                        )));
            case config.destroy:
                return null;
        }
        return state;
    };
};
/**
 * @stable [06.04.2020]
 * @param {IEntityReducerFactoryConfigEntity} config
 * @returns {IEntityActionBuilder<TValue>}
 */
exports.makeEntityActionBuilderFactory = function (config) {
    return Reflect.construct(/** @class */ (function () {
        function class_1() {
        }
        /**
         * @stable [06.04.2020]
         * @param {TPayload} replaced
         * @returns {IEffectsAction}
         */
        class_1.prototype.buildReplaceAction = function (replaced) {
            var payloadWrapper = { replaced: replaced };
            return redux_effects_promise_1.EffectsAction.create(config.replace, payloadWrapper);
        };
        /**
         * @stable [06.04.2020]
         * @returns {IEffectsAction}
         */
        class_1.prototype.buildDestroyAction = function () {
            return redux_effects_promise_1.EffectsAction.create(config.destroy);
        };
        /**
         * @stable [06.04.2020]
         * @param {TPayload} updated
         * @returns {IEffectsAction}
         */
        class_1.prototype.buildUpdateAction = function (updated) {
            var payloadWrapper = { updated: updated };
            return redux_effects_promise_1.EffectsAction.create(config.update, payloadWrapper);
        };
        /**
         * @stable [06.04.2020]
         * @param {TPayload} selected
         * @returns {IEffectsAction}
         */
        class_1.prototype.buildSelectAction = function (selected) {
            var plainAction = this.buildSelectPlainAction(selected);
            return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
        };
        /**
         * @stable [06.04.2020]
         * @param {TValue} selected
         * @returns {IEffectsAction}
         */
        class_1.prototype.buildSelectPlainAction = function (selected) {
            var payloadWrapper = { selected: selected };
            return { type: config.select, data: payloadWrapper };
        };
        return class_1;
    }()), []);
};
//# sourceMappingURL=store.support.js.map