import { IEnvironment, IUpdateEntity } from '../definition';
import { EntityIdT, IEntity, IKeyValue } from '../definitions.interface';
import { INumberConverter } from '../converter';
import { ISettingsEntity } from '../settings';
import { IFieldConverter, IMultiEntityStorageSetEntity, IPlaceEntity, ITransport, ITransportRequestEntity, MultiFieldEntityT, MultiFieldSingleValueT, SelectValueT } from '../definition';
import { IDateConverter } from '../converter';
export declare class BaseTransport {
    protected readonly environment: IEnvironment;
    protected readonly fieldConverter: IFieldConverter;
    protected readonly nc: INumberConverter;
    protected readonly settings: ISettingsEntity;
    protected readonly transport: ITransport;
    /**
     * @stable [16.05.2020]
     * @param {IUpdateEntity<TEntity extends IEntity, TExtraParams>} entity
     * @returns {Promise<TResult>}
     */
    protected doSaveEntity<TEntity extends IEntity = IEntity, TResult = TEntity, TExtraParams = IKeyValue>(entity: IUpdateEntity<TEntity, TExtraParams>): Promise<TResult>;
    /**
     * @stable [17.05.2020]
     * @param {IPlaceEntity} value
     * @returns {string}
     */
    protected fromPlaceEntityToPlaceParameter: (value: IPlaceEntity<string>) => string;
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} entity
     * @returns {TEntity[]}
     */
    protected fromMultiFieldEntityToEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>) => TEntity[];
    /**
     * @stable [16.05.2020]
     * @param {MultiFieldEntityT<TEntity extends IEntity>} entity
     * @returns {TEntity[]}
     */
    protected fromMultiFieldEntityToDefinedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>) => TEntity[];
    /**
     * @stable [16.05.2020]
     * @param {SelectValueT} value
     * @returns {EntityIdT}
     */
    protected fromSelectValueToId: (value: SelectValueT) => string | number;
    /**
     * @stable [04.08.2020]
     * @param value
     * @param converter
     */
    protected numberParameter: (value: string | number, converter?: (value: number) => number) => number;
    /**
     * @stable [14.08.2020]
     * @param value
     */
    protected stringParameter: (value: any) => any;
    /**
     * @stable [14.08.2020]
     * @param value
     */
    protected queryParameter: (value: string) => string;
    /**
     * @stable [25.07.2019]
     * @param {string} value
     * @returns {string}
     */
    protected preparePhoneValue(value: string): string;
    /**
     * @stable [26.12.2019]
     * @param {MultiFieldEntityT | EntityIdT[]} value
     * @returns {EntityIdT[]}
     */
    protected prepareMultiEntitiesIdsValue(value: MultiFieldEntityT | EntityIdT[]): EntityIdT[];
    /**
     * @stable [31.08.2019]
     * @param {ITransportRequestEntity} params
     */
    protected downloadFile(params: ITransportRequestEntity): void;
    /**
     * @stable [03.04.2020]
     * @param {TEntity} entity
     * @param {Array<(entity: TEntity) => MultiFieldSingleValueT>} fieldsValuesResolvers
     * @returns {Promise<IMultiEntityStorageSetEntity[]>}
     */
    protected doSaveMultiEntities<TEntity>(entity: TEntity, ...fieldsValuesResolvers: Array<(entity: TEntity) => MultiFieldSingleValueT>): Promise<IMultiEntityStorageSetEntity[]>;
    /**
     * @lazy
     * @stable [03.04.2020]
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @lazy
     * @stable [03.04.2020]
     * @returns {IStorage}
     */
    private readonly multiEntityDatabaseStorage;
}
