"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var R = require("ramda");
var util_1 = require("../util");
var di_1 = require("../di");
var util_2 = require("../util");
var BaseTransport = /** @class */ (function () {
    function BaseTransport() {
        var _this = this;
        /**
         * @stable [17.05.2020]
         * @param {IPlaceEntity} value
         * @returns {string}
         */
        this.fromPlaceEntityToPlaceParameter = function (value) {
            return _this.fieldConverter.fromPlaceEntityToPlaceParameter(value);
        };
        /**
         * @stable [16.05.2020]
         * @param {MultiFieldEntityT<TEntity extends IEntity>} entity
         * @returns {TEntity[]}
         */
        this.fromMultiFieldEntityToEntities = function (entity) {
            return _this.fieldConverter.fromMultiFieldEntityToEntities(entity);
        };
        /**
         * @stable [16.05.2020]
         * @param {MultiFieldEntityT<TEntity extends IEntity>} entity
         * @returns {TEntity[]}
         */
        this.fromMultiFieldEntityToDefinedEntities = function (entity) {
            return _this.fieldConverter.fromMultiFieldEntityToDefinedEntities(entity);
        };
        /**
         * @stable [16.05.2020]
         * @param {SelectValueT} value
         * @returns {EntityIdT}
         */
        this.fromSelectValueToId = function (value) {
            return _this.fieldConverter.fromSelectValueToId(value);
        };
        /**
         * @stable [04.08.2020]
         * @param value
         * @param converter
         */
        this.numberParameter = function (value, converter) {
            return _this.nc.numberParameter(value, converter);
        };
        /**
         * @stable [14.08.2020]
         * @param value
         */
        this.stringParameter = function (value) { return util_1.StringUtils.asStringParameter(value); };
        /**
         * @stable [14.08.2020]
         * @param value
         */
        this.queryParameter = function (value) { return util_1.StringUtils.asStringParameter(value, true); };
    }
    /**
     * @stable [16.05.2020]
     * @param {IUpdateEntity<TEntity extends IEntity, TExtraParams>} entity
     * @returns {Promise<TResult>}
     */
    BaseTransport.prototype.doSaveEntity = function (entity) {
        var _a = entity.apiEntity, newEntity = _a.newEntity, entityId = _a.entityId, diff = _a.diff;
        return this.transport.request({
            params: __assign({}, diff, util_1.defValuesFilter(entity.extraParams), util_1.defValuesFilter({ id: entityId })),
            name: newEntity ? entity.addApi : entity.editApi,
            operation: entity.operation,
        });
    };
    /**
     * @stable [25.07.2019]
     * @param {string} value
     * @returns {string}
     */
    BaseTransport.prototype.preparePhoneValue = function (value) {
        return util_1.orUndef(!R.isNil(value), function () { return value.replace(/\D/g, ''); });
    };
    /**
     * @stable [26.12.2019]
     * @param {MultiFieldEntityT | EntityIdT[]} value
     * @returns {EntityIdT[]}
     */
    BaseTransport.prototype.prepareMultiEntitiesIdsValue = function (value) {
        return util_2.asMultiFieldMappedEntitiesIds(value);
    };
    /**
     * @stable [31.08.2019]
     * @param {ITransportRequestEntity} params
     */
    BaseTransport.prototype.downloadFile = function (params) {
        var requestParams = this.transport.makeRequestData(params);
        util_1.downloadFileAsBlobUrl(util_1.join([this.settings.downloadUrl, util_1.buildEncodedURI(requestParams)]));
    };
    /**
     * @stable [03.04.2020]
     * @param {TEntity} entity
     * @param {Array<(entity: TEntity) => MultiFieldSingleValueT>} fieldsValuesResolvers
     * @returns {Promise<IMultiEntityStorageSetEntity[]>}
     */
    BaseTransport.prototype.doSaveMultiEntities = function (entity) {
        var _this = this;
        var fieldsValuesResolvers = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            fieldsValuesResolvers[_i - 1] = arguments[_i];
        }
        return util_2.entitiesAsStorageTasks(entity, fieldsValuesResolvers, function (fileName, file) { return _this.multiEntityDatabaseStorage.set(fileName, file); });
    };
    Object.defineProperty(BaseTransport.prototype, "dc", {
        /**
         * @lazy
         * @stable [03.04.2020]
         * @returns {IDateConverter}
         */
        get: function () {
            return di_1.getDateConverter();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseTransport.prototype, "multiEntityDatabaseStorage", {
        /**
         * @lazy
         * @stable [03.04.2020]
         * @returns {IStorage}
         */
        get: function () {
            return di_1.getMultiEntityDatabaseStorage();
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Environment),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "environment", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.FieldConverter),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "fieldConverter", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.NumberConverter),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "nc", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "settings", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Transport),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "transport", void 0);
    BaseTransport = __decorate([
        inversify_1.injectable()
    ], BaseTransport);
    return BaseTransport;
}());
exports.BaseTransport = BaseTransport;
//# sourceMappingURL=base.transport.js.map