"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
/**
 * @stable [31.07.2020]
 * @param entity
 */
var isNewEntity = function (entity) {
    return R.isNil(entity) || R.isNil(entity.id);
};
/**
 * @stable [17.08.2020]
 * @param entity
 */
var isPhantomEntity = function (entity) {
    return !isNewEntity(entity) && entity.id < 0;
};
/**
 * @stable [03.02.2020]
 * @param {IExtendedEntity<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isNewExtendedEntity = function (entity) {
    return R.isNil(entity) || entity.newEntity === true;
};
/**
 * @stable [01.10.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} extendedEntity
 * @returns {boolean}
 */
exports.doesExtendedEntityExist = function (extendedEntity) {
    return !exports.isNewExtendedEntity(extendedEntity);
};
/**
 * @stable [30.08.2019]
 * @param {TEntity} entity
 * @returns {string}
 */
exports.entityAsFileName = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return "" + entity.id + cond_1.ifNotNilThanValue(entity.name, function (name) { return "-" + name.replace(/ /g, '_'); }, ''); }, ''); };
/**
 * @stable [12.10.2019]
 * @param {MultiFieldEntityT | EntityIdT} value
 * @returns {boolean}
 */
exports.isNotMultiEntity = function (value) {
    return Array.isArray(value) || type_1.isPrimitive(value);
};
/**
 * @stable [31.07.2020]
 */
var EntityUtils = /** @class */ (function () {
    function EntityUtils() {
    }
    EntityUtils.isNewEntity = isNewEntity;
    EntityUtils.isPhantomEntity = isPhantomEntity;
    return EntityUtils;
}());
exports.EntityUtils = EntityUtils;
//# sourceMappingURL=entity.js.map