import { IEntity, IKeyValue } from '../definitions.interface';
import { IGenericFieldEntity, IGenericFieldEntity2, IMultiItemEntity, IPresetsFieldEntity, IReduxMultiEntity, MultiFieldEntityT, NotMultiFieldEntityT } from '../definition';
/**
 * @stable [27.08.2019]
 * @param {EntityIdT} key
 * @returns {string}
 */
export declare const dynamicFieldName: (key: string | number) => string;
/**
 * @stable [28.08.2019]
 * @param {TEntity[]} array
 * @param {(itm: TEntity) => EntityIdT} keyAccessor
 * @param {(itm: TEntity) => EntityIdT} valueAccessor
 * @returns {IKeyValue}
 */
export declare const fromDynamicFieldsArray: <TEntity extends string | number | IEntity>(array: TEntity[], keyAccessor: (itm: TEntity) => string | number, valueAccessor: (itm: TEntity) => string | number) => IKeyValue;
/**
 * @stable [14.02.2020]
 * @param {EntityIdT[]} array
 * @param {(itm: EntityIdT) => AnyT} valueAccessor
 * @returns {IKeyValue}
 */
export declare const fromDynamicFieldsIdsArray: (array: (string | number)[], valueAccessor: (itm: string | number) => any) => IKeyValue;
/**
 * @stable [12.10.2019]
 * @param {MultiFieldEntityT} entity
 * @param {Map<EntityIdT, TItem extends IEntity>} mappedSourcedItems
 * @returns {TItem[]}
 */
export declare const asMultiFieldEditedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>, mappedSourcedItems?: Map<string | number, TEntity>) => TEntity[];
/**
 * @stable [22.11.2019]
 * @param {MultiFieldEntityT} entity
 * @returns {TEntity[]}
 */
export declare const asMultiFieldAddedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>) => TEntity[];
/**
 * @stable [14.10.2019]
 * @param {NotMultiFieldEntityT} value
 * @returns {IEntity[]}
 */
export declare const asEntitiesArray: <TEntity extends IEntity = IEntity>(value: NotMultiFieldEntityT<TEntity>) => TEntity[];
/**
 * @stable [14.10.2019]
 * @param {MultiFieldEntityT | EntityIdT} value
 * @returns {number}
 */
export declare const asMultiFieldEntitiesLength: (value: string | number | IEntity[] | IReduxMultiEntity<IEntity>) => number;
/**
 * @stable [14.10.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity>} value
 * @param {number} entitiesCountLimit
 * @returns {TEntity[]}
 */
export declare const asOrderedMultiFieldEntities: <TEntity extends IEntity = IEntity>(value: MultiFieldEntityT<TEntity>, entitiesCountLimit: number) => TEntity[];
/**
 * @stable [14.10.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity>} multiFieldEntity
 * @param {(entity: TEntity, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare const asMultiFieldMappedEntities: <TEntity extends IEntity = IEntity, TResult = TEntity>(multiFieldEntity: IReduxMultiEntity<IEntity> | (string | number)[] | TEntity[], mapper: (entity: TEntity, index: number) => TResult) => TResult[];
/**
 * @stable [14.10.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity> | EntityIdT[]} multiFieldEntity
 * @returns {EntityIdT[]}
 */
export declare const asMultiFieldMappedEntitiesIds: <TEntity extends IEntity = IEntity, TResult = TEntity>(multiFieldEntity: IReduxMultiEntity<IEntity> | (string | number)[] | TEntity[]) => (string | number)[];
/**
 * @stable [22.11.2019]
 * @param {string} name
 * @param {AnyT} value
 * @param {TEntity} rawData
 * @param {boolean} newEntity
 * @returns {IMultiItemEntity}
 */
export declare const buildMultiItemEntity: <TEntity extends IEntity = IEntity>(name: string, value: any, rawData: TEntity, newEntity?: boolean) => IMultiItemEntity;
/**
 * @stable [22.11.2019]
 * @param {Partial<IReduxMultiEntity<TEntity extends IEntity>>} initial
 * @returns {IReduxMultiEntity<TEntity extends IEntity>}
 */
export declare const multiEntityFactory: <TEntity extends IEntity = IEntity>(initial: Partial<IReduxMultiEntity<TEntity>>) => IReduxMultiEntity<TEntity>;
/**
 * @stable [19.11.2019]
 * @param {TEntity} original
 * @param {MultiFieldEntityT<TEntity extends IEntity>} multiFieldEntity
 * @returns {{id: number}}
 */
export declare const buildNewPhantomMultiItem: <TEntity extends IEntity = IEntity>(original: TEntity, multiFieldEntity: MultiFieldEntityT<TEntity>) => TEntity;
/**
 * @stable [16.05.2020]
 */
export declare class FieldUtils {
    static readonly asActualFieldValue: (config: IGenericFieldEntity2) => any;
    static readonly dynamicFieldName: (key: string | number) => string;
    static readonly dynamicFieldValue: <TEntity = IEntity>(object: TEntity, key: string | number) => any;
    static readonly fromMultiFieldEntityToDefinedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>) => TEntity[];
    static readonly fromMultiFieldEntityToEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<TEntity>) => TEntity[];
    static readonly isFieldInactive: (entity: IGenericFieldEntity) => boolean;
    static readonly isFieldReadOnly: (entity: IPresetsFieldEntity) => boolean;
}
