import { AnyT, IEntity, IEntityIdTWrapper, IKeyValue, ITypeWrapper } from '../definitions.interface';
import { IFilterAndSorterConfiguration } from '../configurations-definitions.interface';
export declare type KeyValuePredicateT = (key: string, value: AnyT) => boolean;
export declare type ValuePredicateT = (value: AnyT) => boolean;
export declare function cloneUsingFilters<TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...predicates: KeyValuePredicateT[]): TResult;
/**
 * @stable [11.08.2018]
 * @param {TSource} source
 * @param {KeyValuePredicateT} predicates
 * @returns {TResult}
 */
export declare const filterByPredicate: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...predicates: KeyValuePredicateT[]) => TResult;
/**
 * @stable [09.01.2019]
 * @param {IEntity} entity1
 * @param {IEntity} entity2
 */
export declare const SAME_ENTITY_PREDICATE: <TEntity extends IEntityIdTWrapper = IEntityIdTWrapper>(entity1: TEntity, entity2: TEntity) => boolean;
/**
 * @stable [03.04.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
export declare const EVENT_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [03.10.2019]
 * @param {string} key
 * @param {AnyT} value
 * @returns {boolean}
 */
export declare const OBJECT_KEY_VALUE_PREDICATE: (key: string, value: any) => boolean;
/**
 * @stable [03.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
export declare const NOT_OBJECT_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [03.10.2019]
 * @param {string} key
 * @param {AnyT} value
 * @returns {boolean}
 */
export declare const NOT_OBJECT_KEY_VALUE_PREDICATE: (key: string, value: any) => boolean;
/**
 * @stable [03.10.2019]
 * @param {string} key
 * @param {AnyT} value
 * @returns {boolean}
 */
export declare const NOT_NIL_KEY_VALUE_PREDICATE: (key: string, value: any) => boolean;
/**
 * @stable [22.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 * @constructor
 */
export declare const TRUE_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [22.10.2019]
 * @param {TValue} data
 * @returns {TValue[]}
 */
export declare const trueValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
/**
 * @stable [25.12.2019]
 * @param {TValue} data
 * @returns {TValue[]}
 */
export declare const stringValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
export declare function excludeFieldsFilter<TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...fields: string[]): TResult;
/**
 * @stable [27.07.2020]
 * @param source
 */
export declare const defValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
/**
 * @stable [31.01.2019]
 * @param {TSource} source
 * @returns {TResult}
 */
export declare const notNilValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
export declare const excludeIdFieldFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
/**
 * @stable [16.06.2018]
 * @param {TEntity[] | TEntity} data
 * @param {IFilterAndSorterConfiguration} config
 * @returns {TEntity[]}
 */
export declare const filterAndSortEntities: <TEntity = IEntity>(data: TEntity | TEntity[], config?: IFilterAndSorterConfiguration) => TEntity[];
/**
 * @stable [06.04.2020]
 * @param {TValue[]} data
 * @param {TType} type
 * @returns {TValue}
 */
export declare const findByType: <TValue extends ITypeWrapper<TType>, TType>(data: TValue[], type: TType) => TValue;
/**
 * @stable [15.05.2020]
 */
export declare class FilterUtils {
    static readonly defValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
    static readonly defValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
    static readonly EXCLUDE_ENTITY_ID_FIELD_PREDICATE: (key: string) => boolean;
    static readonly EXCLUDE_ID_FIELD_PREDICATE: (key: string) => boolean;
    static readonly excludeFieldsPredicateFactory: (...fields: string[]) => (key: string) => boolean;
    static readonly NOT_NIL_VALUE_PREDICATE: (value: any) => boolean;
    static readonly notEmptyValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
    static readonly notEmptyValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
    static readonly notNilValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
    static readonly notNilValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
    static readonly OBJECT_VALUE_PREDICATE: (value: any) => boolean;
    static readonly objectValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
    static readonly positiveOrNegativeNumberLikeValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
    static readonly queryFilter: (query: string, ...items: (string | number)[]) => boolean;
    static readonly SAME_ENTITY_PREDICATE: <TEntity extends IEntityIdTWrapper = IEntityIdTWrapper>(entity1: TEntity, entity2: TEntity) => boolean;
    static readonly STRING_VALUE_PREDICATE: (value: any) => boolean;
}
