import { IOperationEntity, IReduxSortDirectionsEntity, IReduxTransportHolderEntity, ISortDirectionEntity, ISortDirectionsEntity, IUniversalApplicationEntity } from '../definition';
import { IEntityIdTWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @returns {string}
 */
export declare const selectTransportWrapperToken: (entity: IReduxTransportHolderEntity<import("../definition").IReduxTransportEntity>) => string;
/**
 * @stable [25.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @returns {string[]}
 */
export declare const selectTransportWrapperQueue: (entity: IReduxTransportHolderEntity<import("../definition").IReduxTransportEntity>) => string[];
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: IReduxSortDirectionsEntity) => ISortDirectionsEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasQueueOperations: (queue: string[], ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [25.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasTransportWrapperQueueOperations: (entity: IReduxTransportHolderEntity<import("../definition").IReduxTransportEntity>, ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationInProgress: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const doesApplicationErrorExist: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationMessageVisible: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [05.05.2020]
 */
export declare class Mappers {
    static readonly containerAsUnsavedFormChangesDialogContainerProps: (proxyContainer: import("../definition").IGenericContainer<import("../definition").IUnsavedFormChangesDialogContainerProps, {}>) => import("../definition").IUnsavedFormChangesDialogContainerProps;
    static readonly defaultLayoutContainerProps: (defaultLayoutContainer: import("../definition").IDefaultLayoutContainerProps) => import("../definition").IDefaultLayoutContainerProps;
    static readonly defaultLayoutPropsAsHeaderProps: (defaultLayout: import("../definition").IDefaultLayoutProps) => import("../definition").IHeaderProps;
    static readonly dictionariesContainerAsParameterizedSelectProps: <TDictionary extends import("../definition").IReduxBaseDictionariesEntity = import("../definition").IReduxDictionariesEntity, TEntity = import("../definitions.interface").IEntity, TResult = TEntity[], TPayload = {}>(cfg: import("./map-as-component").IDictionariesContainerAsParameterizedSelectPropsConfigEntity<TDictionary, TEntity, TResult, TPayload>) => import("../definition").IBaseSelectProps;
    static readonly dictionariesContainerAsPlaceFieldProps: (container: import("../definition").IDictionariesContainer<import("../definition").IReduxBaseDictionariesEntity>) => import("../definition").IBaseSelectProps;
    static readonly dictionariesContainerAsSelectProps: <TDictionary extends import("../definition").IReduxBaseDictionariesEntity = import("../definition").IReduxDictionariesEntity, TEntity = import("../definitions.interface").IEntity, TResult = TEntity[]>(cfg: import("./map-as-component").IDictionariesContainerAsSelectPropsConfigEntity<TDictionary, TEntity, TResult>) => import("../definition").IBaseSelectProps;
    static readonly dictionaryEntityAsDisabled: (dictionaryEntity: import("../definition").IReduxDictionaryEntity<import("../definitions.interface").IKeyValue>) => import("../definitions.interface").IDisabledWrapper<boolean>;
    static readonly dictionaryEntityAsProgress: (dictionaryEntity: import("../definition").IReduxDictionaryEntity<import("../definitions.interface").IKeyValue>) => import("../definitions.interface").IProgressWrapper<boolean>;
    static readonly dictionaryEntityAsSelectEntity: <TEntity, TResult = TEntity[]>(entity: import("../definition").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity[]) => TResult) => import("../definition").IPresetsBaseSelectEntity;
    static readonly dictionaryEntityAsSelectOptionEntities: <TEntity>(dictionaryEntity: import("../definition").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => any) => import("../definition").IPresetsSelectOptionEntity<TEntity, string | number>[];
    static readonly entityAsExtendedEntity: <TEntity extends import("../definitions.interface").IEntity = import("../definitions.interface").IEntity>(formEntity: import("../definition").IReduxFormEntity<TEntity>, entity?: TEntity) => import("../definition").IExtendedEntity<TEntity>;
    static readonly entityAsExtendedFormEntity: <TEntity = import("../definitions.interface").IEntity>(formEntity: import("../definition").IReduxFormEntity<TEntity>, entity?: TEntity) => import("../definition").IExtendedFormEntity<TEntity>;
    static readonly entityAsFullSearchFilter: <TFilter, TEntity = import("../definitions.interface").IEntity>(entity: import("../definition").IReduxQueryFilterHolderEntity & import("../definition").IReduxListHolderEntity<TEntity, any, import("../definition").IReduxListEntity<TEntity, any>> & import("../definitions.interface").IPrimaryFilterWrapper<TFilter> & import("../definitions.interface").ISecondaryFilterWrapper<TFilter>, cfg?: {
        paging: boolean;
    }) => TFilter;
    static readonly extendedEntity: <TEntity = import("../definitions.interface").IEntity>(extendedEntity: import("../definition").IExtendedEntity<TEntity>) => import("../definition").IExtendedEntity<TEntity>;
    static readonly extendedEntityAsApiEntity: <TEntity = import("../definitions.interface").IEntity>(extendedEntity: import("../definition").IExtendedEntity<TEntity>) => import("../definition").IApiEntity<TEntity>;
    static readonly filterFormDialogContainerProps: (filterFormDialogContainer: import("../definition").IFilterFormDialogContainerProps) => import("../definition").IFilterFormDialogContainerProps;
    static readonly form: <TForm>(form: TForm) => import("../definitions.interface").IFormWrapper<TForm>;
    static readonly formContainerProps: (formContainer: import("../definition").IFormContainerProps<import("../definitions.interface").IEntity, {}>) => import("../definition").IFormContainerProps<import("../definitions.interface").IEntity, {}>;
    static readonly formContainerPropsAsFormProps: (formContainer: import("../definition").IFormContainerProps<import("../definitions.interface").IEntity, {}>) => import("../definition").IFormProps<import("../definitions.interface").IEntity>;
    static readonly formEntityAsFinalEntity: <TEntity = import("../definitions.interface").IEntity>(formEntity: import("../definition").IReduxFormEntity<TEntity>, entity?: TEntity) => TEntity;
    static readonly formHolderEntity: <TEntity = import("../definitions.interface").IEntity>(entity: import("../definition").IReduxFormHolderEntity<TEntity>) => import("../definition").IReduxFormHolderEntity<TEntity>;
    static readonly formTabPanelContainerProps: (formTabPanelContainer: import("../definition").IFormTabPanelContainerProps<import("../definitions.interface").IEntity>) => import("../definition").IFormTabPanelContainerProps<import("../definitions.interface").IEntity>;
    static readonly formTabPanelContainerPropsAsTabPanelProps: (formTabPanelContainer: import("../definition").IFormTabPanelContainerProps<import("../definitions.interface").IEntity>) => import("../definition").ITabPanelProps;
    static readonly listContainerProps: (listContainer: import("../definition").IListContainerProps) => import("../definition").IListContainerProps;
    static readonly listHolderEntity: (entity: import("../definition").IReduxListHolderEntity<import("../definitions.interface").IEntity, any, import("../definition").IReduxListEntity<import("../definitions.interface").IEntity, any>>) => import("../definition").IReduxListHolderEntity<import("../definitions.interface").IEntity, any, import("../definition").IReduxListEntity<import("../definitions.interface").IEntity, any>>;
    static readonly listHolderEntityAsDisabled: (listEntity: import("../definition").IReduxListHolderEntity<import("../definitions.interface").IEntity, any, import("../definition").IReduxListEntity<import("../definitions.interface").IEntity, any>>) => import("../definitions.interface").IDisabledWrapper<boolean>;
    static readonly listHolderEntityAsPagedEntity: (entity: import("../definition").IReduxListHolderEntity<import("../definitions.interface").IEntity, any, import("../definition").IReduxListEntity<import("../definitions.interface").IEntity, any>>, pageSize?: number) => import("../definition").IReduxPagedEntity;
    static readonly listPropsAsBasicListProps: (list: import("../definition").IListProps) => import("../definition").IBasicListProps;
    static readonly listSelectedEntityAsExtendedFormEntity: <TEntity = import("../definitions.interface").IEntity>(listHolderEntity: import("../definition").IReduxListHolderEntity<TEntity, any, import("../definition").IReduxListEntity<TEntity, any>>, formEntity: import("../definition").IReduxFormEntity<TEntity>) => import("../definition").IExtendedFormEntity<TEntity>;
    static readonly listSelectedEntityAsFinalEntity: <TEntity = import("../definitions.interface").IEntity>(listHolderEntity: import("../definition").IReduxListHolderEntity<TEntity, any, import("../definition").IReduxListEntity<TEntity, any>>, formEntity: import("../definition").IReduxFormEntity<TEntity>) => TEntity;
    static readonly namedEntityAsRawDataLabeledValueEntity: (entity: import("../definition").INamedEntity) => import("../definition").IPresetsRawDataLabeledValueEntity<import("../definitions.interface").IEntity, string | number>;
    static readonly optionEntitiesAsSelectOptionEntities: <TEntity extends import("../definition").IOptionEntity>(data: TEntity | TEntity[]) => import("../definition").IPresetsSelectOptionEntity<TEntity, string | number>[];
    static readonly pagedEntity: (entity: import("../definition").IReduxPagedEntity) => import("../definition").IReduxPagedEntity;
    static readonly pageToolbarContainerProps: (pageToolbarContainer: import("../definition").IPageToolbarContainerProps) => import("../definition").IPageToolbarContainerProps;
    static readonly pageToolbarContainerPropsAsPageToolbarProps: (pageToolbarContainer: import("../definition").IPageToolbarContainerProps) => import("../definition").IPageToolbarProps;
    static readonly paginatedEntity: (entity: import("../definition").IReduxPaginatedEntity) => import("../definition").IReduxPaginatedEntity;
    static readonly primaryFilterExtendedFormEntityAsFilterFormDialogContainerProps: (entity: import("../definition").IFilterFormDialogContainerProps & import("../definition").IPrimaryFilterExtendedFormEntity<import("../definitions.interface").IEntity>) => import("../definition").IFilterFormDialogContainerProps;
    static readonly primaryFilterExtendedFormEntityAsFormContainerProps: <TValue = import("../definitions.interface").IEntity>(entity: import("../definitions.interface").ISectionNameWrapper & import("../definition").IPrimaryFilterExtendedFormEntity<TValue>) => import("../definition").IFormContainerProps<import("../definitions.interface").IEntity, {}>;
    static readonly primaryFilterFormEntityAsPrimaryFilterExtendedFormEntity: <TEntity = import("../definitions.interface").IEntity>(primaryFilterFormEntity: import("../definition").IReduxPrimaryFilterFormEntity<TEntity>, entity?: TEntity) => import("../definition").IPrimaryFilterExtendedFormEntity<TEntity>;
    static readonly primaryFilterFormHolderEntityAsToolbarToolsContainerProps: (entity: import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps> & import("../definition").IReduxPrimaryFilterFormHolderEntity<import("../definitions.interface").IEntity>) => import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps>;
    static readonly queryFilterHolderEntity: (entity: import("../definition").IReduxQueryFilterHolderEntity) => import("../definition").IReduxQueryFilterHolderEntity;
    static readonly queryFilterHolderEntityAsQuery: (entity: import("../definition").IReduxQueryFilterHolderEntity) => import("../definitions.interface").IQueryWrapper<string>;
    static readonly searchToolbarContainerProps: (searchToolbarContainer: import("../definition").ISearchToolbarContainerProps) => import("../definition").ISearchToolbarContainerProps;
    static readonly searchToolbarContainerPropsAsSearchToolbarProps: (searchToolbarContainer: import("../definition").ISearchToolbarContainerProps) => import("../definition").ISearchToolbarProps;
    static readonly secondaryFilterExtendedFormEntityAsFilterFormDialogContainerProps: (entity: import("../definition").IFilterFormDialogContainerProps & import("../definition").ISecondaryFilterExtendedFormEntity<import("../definitions.interface").IEntity>) => import("../definition").IFilterFormDialogContainerProps;
    static readonly secondaryFilterExtendedFormEntityAsFormContainerProps: <TValue = import("../definitions.interface").IEntity>(entity: import("../definitions.interface").ISectionNameWrapper & import("../definition").ISecondaryFilterExtendedFormEntity<TValue>) => import("../definition").IFormContainerProps<import("../definitions.interface").IEntity, {}>;
    static readonly secondaryFilterFormEntityAsSecondaryFilterExtendedFormEntity: <TEntity = import("../definitions.interface").IEntity>(secondaryFilterFormEntity: import("../definition").IReduxSecondaryFilterFormEntity<TEntity>, entity?: TEntity) => import("../definition").ISecondaryFilterExtendedFormEntity<TEntity>;
    static readonly secondaryFilterFormHolderEntityAsToolbarToolsContainerProps: (entity: import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps> & import("../definition").IReduxSecondaryFilterFormHolderEntity<import("../definitions.interface").IEntity>) => import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps>;
    static readonly sectionNameWrapper: (wrapper: import("../definitions.interface").ISectionNameWrapper) => import("../definitions.interface").ISectionNameWrapper;
    static readonly storeBaseEntity: <TDictionaries = {}>(entity: import("../definition").IReduxStoreEntity<TDictionaries>) => import("../definition").IReduxStoreEntity<TDictionaries>;
    static readonly storeEntity: <TDictionaries = {}>(entity: import("../definition").IReduxStoreEntity<TDictionaries>) => import("../definition").IReduxStoreEntity<TDictionaries>;
    static readonly tabPanelContainerProps: (tabPanelContainer: import("../definition").ITabPanelContainerProps) => import("../definition").ITabPanelContainerProps;
    static readonly tabPanelContainerPropsAsTabPanelProps: (tabPanelContainer: import("../definition").ITabPanelContainerProps) => import("../definition").ITabPanelProps;
    static readonly tabPanelHolderEntity: <TEntity = import("../definition").IReduxTabPanelEntity>(entity: import("../definition").IReduxTabPanelHolderEntity<TEntity>) => import("../definition").IReduxTabPanelHolderEntity<TEntity>;
    static readonly toolbarToolsContainerProps: (toolbarToolsContainer: import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps>) => import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps>;
    static readonly toolbarToolsContainerPropsAsToolbarToolsProps: (toolbarToolsContainer: import("../definition").IToolbarToolsContainerProps<import("../definition").IToolbarToolsProps>) => import("../definition").IToolbarToolsProps;
    static readonly toolbarToolsProps: (toolbarTools: import("../definition").IToolbarToolsProps) => import("../definition").IToolbarToolsProps;
    static readonly unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps: (unsavedFormChangesDialogContainer: import("../definition").IUnsavedFormChangesDialogContainerProps) => import("../definition").IUnsavedFormChangesDialogProps;
    static readonly unsavedFormChangesDialogProps: <TEntity = import("../definitions.interface").IEntity>(unsavedFormChangesDialog: import("../definition").IUnsavedFormChangesDialogProps) => import("../definition").IUnsavedFormChangesDialogProps;
}
