"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var type_1 = require("./type");
var wrapper_1 = require("./wrapper");
var select_1 = require("./select");
var map_as_component_1 = require("./map-as-component");
var map_as_original_1 = require("./map-as-original");
var map_as_1 = require("./map-as");
var map_as_wrapper_1 = require("./map-as-wrapper");
/**
 * @stable [17.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @returns {string}
 */
exports.selectTransportWrapperToken = function (entity) {
    return select_1.selectToken(select_1.Selectors.transport(entity));
};
/**
 * @stable [25.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @returns {string[]}
 */
exports.selectTransportWrapperQueue = function (entity) {
    return select_1.Selectors.queue(select_1.Selectors.transport(entity));
};
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
exports.mapEntityId = function (id) {
    return filter_1.defValuesFilter({ id: id });
};
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
exports.mapSortDirectionsWrapperEntity = function (directions) {
    return filter_1.defValuesFilter({ directions: directions });
};
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
exports.mapIdentifiedEntity = function (entity) {
    return exports.mapEntityId(select_1.Selectors.entityId(entity));
};
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
exports.mapSortDirectionEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    index: entity.index,
    direction: entity.direction,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasQueueOperations = function (queue) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return !R.isEmpty(R.intersection(queue, operations.map(function (operation) { return (type_1.TypeUtils.isString(operation)
        ? operation
        : operation.id); })));
};
/**
 * @stable [25.11.2019]
 * @param {IReduxTransportHolderEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasTransportWrapperQueueOperations = function (entity) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return exports.hasQueueOperations.apply(void 0, [exports.selectTransportWrapperQueue(entity)].concat(operations));
};
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationInProgress = function (entity) { return wrapper_1.WrapperUtils.inProgress(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.doesApplicationErrorExist = function (entity) { return wrapper_1.doesErrorExist(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationMessageVisible = function (entity) {
    return exports.isApplicationInProgress(entity) || exports.doesApplicationErrorExist(entity) || !wrapper_1.isReady(entity);
};
/**
 * @stable [05.05.2020]
 */
// tslint:disable:max-line-length
var Mappers = /** @class */ (function () {
    function Mappers() {
    }
    Mappers.containerAsUnsavedFormChangesDialogContainerProps = map_as_component_1.MapAsComponentUtils.containerAsUnsavedFormChangesDialogContainerProps; /* @stable [06.08.2020] */
    Mappers.defaultLayoutContainerProps = map_as_component_1.MapAsComponentUtils.defaultLayoutContainerProps; /* @stable [01.08.2020] */
    Mappers.defaultLayoutPropsAsHeaderProps = map_as_component_1.MapAsComponentUtils.defaultLayoutPropsAsHeaderProps; /* @stable [12.08.2020] */
    Mappers.dictionariesContainerAsParameterizedSelectProps = map_as_component_1.MapAsComponentUtils.dictionariesContainerAsParameterizedSelectProps; /* @stable [07.08.2020] */
    Mappers.dictionariesContainerAsPlaceFieldProps = map_as_component_1.MapAsComponentUtils.dictionariesContainerAsPlaceFieldProps; /* @stable [07.08.2020] */
    Mappers.dictionariesContainerAsSelectProps = map_as_component_1.MapAsComponentUtils.dictionariesContainerAsSelectProps; /* @stable [07.08.2020] */
    Mappers.dictionaryEntityAsDisabled = map_as_1.MapAsUtils.dictionaryEntityAsDisabled; /* @stable [10.08.2020] */
    Mappers.dictionaryEntityAsProgress = map_as_1.MapAsUtils.dictionaryEntityAsProgress; /* @stable [10.08.2020] */
    Mappers.dictionaryEntityAsSelectEntity = map_as_1.MapAsUtils.dictionaryEntityAsSelectEntity; /* @stable [06.08.2020] */
    Mappers.dictionaryEntityAsSelectOptionEntities = map_as_1.MapAsUtils.dictionaryEntityAsSelectOptionEntities; /* @stable [02.08.2020] */
    Mappers.entityAsExtendedEntity = map_as_1.MapAsUtils.entityAsExtendedEntity; /* @stable [31.07.2020] */
    Mappers.entityAsExtendedFormEntity = map_as_1.MapAsUtils.entityAsExtendedFormEntity; /* @stable [31.07.2020] */
    Mappers.entityAsFullSearchFilter = map_as_1.MapAsUtils.entityAsFullSearchFilter; /* @stable [02.08.2020] */
    Mappers.extendedEntity = map_as_original_1.MapAsOriginalUtils.extendedEntity; /* @stable [31.07.2020] */
    Mappers.extendedEntityAsApiEntity = map_as_1.MapAsUtils.extendedEntityAsApiEntity; /* @stable [31.07.2020] */
    Mappers.filterFormDialogContainerProps = map_as_component_1.MapAsComponentUtils.filterFormDialogContainerProps; /* @stable [02.08.2020] */
    Mappers.form = map_as_wrapper_1.MapAsWrapperUtils.form; /* @stable [27.07.2020] */
    Mappers.formContainerProps = map_as_component_1.MapAsComponentUtils.formContainerProps; /* @stable [30.07.2020] */
    Mappers.formContainerPropsAsFormProps = map_as_component_1.MapAsComponentUtils.formContainerPropsAsFormProps; /* @stable [31.07.2020] */
    Mappers.formEntityAsFinalEntity = map_as_1.MapAsUtils.formEntityAsFinalEntity; /* @stable [02.08.2020] */
    Mappers.formHolderEntity = map_as_original_1.MapAsOriginalUtils.formHolderEntity; /* @stable [30.07.2020] */
    Mappers.formTabPanelContainerProps = map_as_component_1.MapAsComponentUtils.formTabPanelContainerProps; /* @stable [30.07.2020] */
    Mappers.formTabPanelContainerPropsAsTabPanelProps = map_as_component_1.MapAsComponentUtils.formTabPanelContainerPropsAsTabPanelProps; /* @stable [30.07.2020] */
    Mappers.listContainerProps = map_as_component_1.MapAsComponentUtils.listContainerProps; /* @stable [31.07.2020] */
    Mappers.listHolderEntity = map_as_original_1.MapAsOriginalUtils.listHolderEntity; /* @stable [31.07.2020] */
    Mappers.listHolderEntityAsDisabled = map_as_1.MapAsUtils.listHolderEntityAsDisabled; /* @stable [31.07.2020] */
    Mappers.listHolderEntityAsPagedEntity = map_as_1.MapAsUtils.listHolderEntityAsPagedEntity; /* @stable [02.08.2020] */
    Mappers.listPropsAsBasicListProps = map_as_component_1.MapAsComponentUtils.listPropsAsBasicListProps; /* @stable [17.08.2020] */
    Mappers.listSelectedEntityAsExtendedFormEntity = map_as_1.MapAsUtils.listSelectedEntityAsExtendedFormEntity; /* @stable [01.08.2020] */
    Mappers.listSelectedEntityAsFinalEntity = map_as_1.MapAsUtils.listSelectedEntityAsFinalEntity; /* @stable [01.08.2020] */
    Mappers.namedEntityAsRawDataLabeledValueEntity = map_as_1.MapAsUtils.namedEntityAsRawDataLabeledValueEntity; /* @stable [02.08.2020] */
    Mappers.optionEntitiesAsSelectOptionEntities = map_as_1.MapAsUtils.optionEntitiesAsSelectOptionEntities; /* @stable [02.08.2020] */
    Mappers.pagedEntity = map_as_original_1.MapAsOriginalUtils.pagedEntity; /* @stable [31.07.2020] */
    Mappers.pageToolbarContainerProps = map_as_component_1.MapAsComponentUtils.pageToolbarContainerProps; /* @stable [31.07.2020] */
    Mappers.pageToolbarContainerPropsAsPageToolbarProps = map_as_component_1.MapAsComponentUtils.pageToolbarContainerPropsAsPageToolbarProps; /* @stable [31.07.2020] */
    Mappers.paginatedEntity = map_as_original_1.MapAsOriginalUtils.paginatedEntity; /* @stable [31.07.2020] */
    Mappers.primaryFilterExtendedFormEntityAsFilterFormDialogContainerProps = map_as_component_1.MapAsComponentUtils.primaryFilterExtendedFormEntityAsFilterFormDialogContainerProps; /* @stable [02.08.2020] */
    Mappers.primaryFilterExtendedFormEntityAsFormContainerProps = map_as_component_1.MapAsComponentUtils.primaryFilterExtendedFormEntityAsFormContainerProps; /* @stable [01.08.2020] */
    Mappers.primaryFilterFormEntityAsPrimaryFilterExtendedFormEntity = map_as_1.MapAsUtils.primaryFilterFormEntityAsPrimaryFilterExtendedFormEntity; /* @stable [02.08.2020] */
    Mappers.primaryFilterFormHolderEntityAsToolbarToolsContainerProps = map_as_component_1.MapAsComponentUtils.primaryFilterFormHolderEntityAsToolbarToolsContainerProps; /* @stable [01.08.2020] */
    Mappers.queryFilterHolderEntity = map_as_original_1.MapAsOriginalUtils.queryFilterHolderEntity; /* @stable [31.07.2020] */
    Mappers.queryFilterHolderEntityAsQuery = map_as_1.MapAsUtils.queryFilterHolderEntityAsQuery; /* @stable [02.08.2020] */
    Mappers.searchToolbarContainerProps = map_as_component_1.MapAsComponentUtils.searchToolbarContainerProps; /* @stable [31.07.2020] */
    Mappers.searchToolbarContainerPropsAsSearchToolbarProps = map_as_component_1.MapAsComponentUtils.searchToolbarContainerPropsAsSearchToolbarProps; /* @stable [31.07.2020] */
    Mappers.secondaryFilterExtendedFormEntityAsFilterFormDialogContainerProps = map_as_component_1.MapAsComponentUtils.secondaryFilterExtendedFormEntityAsFilterFormDialogContainerProps; /* @stable [02.08.2020] */
    Mappers.secondaryFilterExtendedFormEntityAsFormContainerProps = map_as_component_1.MapAsComponentUtils.secondaryFilterExtendedFormEntityAsFormContainerProps; /* @stable [01.08.2020] */
    Mappers.secondaryFilterFormEntityAsSecondaryFilterExtendedFormEntity = map_as_1.MapAsUtils.secondaryFilterFormEntityAsSecondaryFilterExtendedFormEntity; /* @stable [02.08.2020] */
    Mappers.secondaryFilterFormHolderEntityAsToolbarToolsContainerProps = map_as_component_1.MapAsComponentUtils.secondaryFilterFormHolderEntityAsToolbarToolsContainerProps; /* @stable [01.08.2020] */
    Mappers.sectionNameWrapper = map_as_original_1.MapAsOriginalUtils.sectionNameWrapper; /* @stable [30.07.2020] */
    Mappers.storeBaseEntity = map_as_original_1.MapAsOriginalUtils.storeBaseEntity; /* @stable [31.07.2020] */
    Mappers.storeEntity = map_as_original_1.MapAsOriginalUtils.storeEntity; /* @stable [31.07.2020] */
    Mappers.tabPanelContainerProps = map_as_component_1.MapAsComponentUtils.tabPanelContainerProps; /* @stable [30.07.2020] */
    Mappers.tabPanelContainerPropsAsTabPanelProps = map_as_component_1.MapAsComponentUtils.tabPanelContainerPropsAsTabPanelProps; /* @stable [30.07.2020] */
    Mappers.tabPanelHolderEntity = map_as_original_1.MapAsOriginalUtils.tabPanelHolderEntity; /* @stable [29.07.2020] */
    Mappers.toolbarToolsContainerProps = map_as_component_1.MapAsComponentUtils.toolbarToolsContainerProps; /* @stable [01.08.2020] */
    Mappers.toolbarToolsContainerPropsAsToolbarToolsProps = map_as_component_1.MapAsComponentUtils.toolbarToolsContainerPropsAsToolbarToolsProps; /* @stable [01.08.2020] */
    Mappers.toolbarToolsProps = map_as_component_1.MapAsComponentUtils.toolbarToolsProps; /* @stable [01.08.2020] */
    Mappers.unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps = map_as_component_1.MapAsComponentUtils.unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps; /* @stable [01.08.2020] */
    Mappers.unsavedFormChangesDialogProps = map_as_component_1.MapAsComponentUtils.unsavedFormChangesDialogProps; /* @stable [01.08.2020] */
    return Mappers;
}());
exports.Mappers = Mappers;
// tslint:enable:max-line-length
//# sourceMappingURL=mapper.js.map