"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
var default_definition_interface_1 = require("../definition/default-definition.interface");
/**
 * @stable [24.07.2020]
 * @param num
 * @param precision
 */
var roundByPrecision = function (num, precision) {
    if (precision === void 0) { precision = default_definition_interface_1.DefaultEntities.CURRENCY_PRECISION_VALUE; }
    return Number(Math.round(Number(num + "e" + precision)) + "e-" + precision);
};
/**
 * @stable [05.05.2019]
 * @param {number} num
 * @param {number} divider
 * @returns {number}
 */
exports.roundDownByDivider = function (num, divider) {
    return Math.floor(num - num % divider);
};
/**
 * @stable [24.07.2020]
 * @param num
 */
var invert = function (num) { return num === 0 ? num : num * -1; }; // To exclude the "-0" case
/**
 * @stable [24.07.2020]
 * @param num
 * @param precision
 */
var invertCurrency = function (num, precision) {
    if (precision === void 0) { precision = default_definition_interface_1.DefaultEntities.CURRENCY_PRECISION_VALUE; }
    return invert(roundByPrecision(num, precision));
};
/**
 * @stable [26.06.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.percent = function (value, total) { return total === 0 ? 0 : (value * 100) / total; };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.proportion = function (value, total) { return (value * total) / 100; };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @returns {number}
 */
exports.residueRoundDownByDivider = function (value, total) { return total - exports.roundDownByDivider(total, value); };
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @param {number} offValue
 * @returns {number}
 */
exports.roundedProportion = function (value, total, offValue) {
    if (offValue === void 0) { offValue = definitions_interface_1.ONE_DOLLAR_VALUE; }
    var result0 = exports.proportion(value, total);
    return result0 + exports.residueRoundDownByDivider(offValue, total - result0);
};
/**
 * @stable [12.09.2019]
 * @param {number} value
 * @param {number} total
 * @param {number} offValue
 * @param {number} precisionValue
 * @returns {number}
 */
exports.roundedByPrecisionProportion = function (value, total, offValue, precisionValue) {
    if (offValue === void 0) { offValue = definitions_interface_1.ONE_DOLLAR_VALUE; }
    if (precisionValue === void 0) { precisionValue = default_definition_interface_1.DefaultEntities.CURRENCY_PRECISION_VALUE; }
    return roundByPrecision(exports.roundedProportion(value, total, offValue), precisionValue);
};
/**
 * @stable [17.08.2020]
 * @param value
 */
var isOddNumber = function (value) { return value % 2 !== 0; };
/**
 * @stable [29.06.2020]
 */
var NumberUtils = /** @class */ (function () {
    function NumberUtils() {
    }
    NumberUtils.invert = invert;
    NumberUtils.invertCurrency = invertCurrency;
    NumberUtils.isOddNumber = isOddNumber;
    NumberUtils.roundByPrecision = roundByPrecision;
    return NumberUtils;
}());
exports.NumberUtils = NumberUtils;
//# sourceMappingURL=number.js.map