"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var type_1 = require("./type");
/**
 * @stable [18.04.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isObjectNotEmpty = function (o) { return !R.isNil(o) && !R.isEmpty(o); };
/**
 * @stable [18.04.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isObjectEmpty = function (o) { return !exports.isObjectNotEmpty(o); };
/**
 * @stable [18.03.2020]
 * @param {AnyT} o
 * @returns {boolean}
 */
exports.isStringNotEmpty = function (o) { return type_1.TypeUtils.isString(o) && exports.isObjectNotEmpty(o); };
/**
 * @stable [20.03.2019]
 * @param {AnyT} current
 * @param {AnyT} previous
 * @returns {boolean}
 */
var isCurrentValueNotEqualPreviousValue = function (current, previous) {
    return exports.isObjectNotEmpty(current) && !R.equals(current, previous);
};
/**
 * @stable [17.04.2020]
 * @param {TValue} object
 * @param {(o, key) => any} mergeFn
 * @returns {TValue}
 */
var buildValuesObjectBy = function (object, mergeFn) {
    if (mergeFn === void 0) { mergeFn = function (o, key) { return o[key]; }; }
    return R.isNil(object)
        ? object
        : R.mergeAll(Object.keys(object).map(function (key) {
            var _a;
            return (_a = {}, _a[key] = mergeFn(object, key), _a);
        }));
};
/**
 * @stable [15.05.2020]
 * @param {TValue} object
 * @returns {TValue}
 */
var buildUndefValuesObject = function (object) { return buildValuesObjectBy(object, function () { return definitions_interface_1.UNDEF; }); };
/**
 * @stable [16.05.2020]
 * @param {TValue} object
 * @returns {TValue}
 */
var buildNotEmptyOrNullValuesObject = function (object) { return buildValuesObjectBy(object, function (o, key) {
    var value = object[key];
    return exports.isObjectNotEmpty(value) ? value : null;
}); };
/**
 * @stable [15.05.2020]
 */
var ObjectUtils = /** @class */ (function () {
    function ObjectUtils() {
    }
    ObjectUtils.buildNotEmptyOrNullValuesObject = buildNotEmptyOrNullValuesObject; /* @stable [15.05.2020] */
    ObjectUtils.buildUndefValuesObject = buildUndefValuesObject; /* @stable [15.05.2020] */
    ObjectUtils.buildValuesObjectBy = buildValuesObjectBy; /* @stable [15.05.2020] */
    ObjectUtils.isCurrentValueNotEqualPreviousValue = isCurrentValueNotEqualPreviousValue; /* @stable [15.05.2020] */
    ObjectUtils.isObjectNotEmpty = exports.isObjectNotEmpty; /* @stable [15.05.2020] */
    return ObjectUtils;
}());
exports.ObjectUtils = ObjectUtils;
//# sourceMappingURL=object.js.map