"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var nvl_1 = require("./nvl");
var type_1 = require("./type");
var calc_1 = require("./calc");
var filter_1 = require("./filter");
/**
 * @stable [04.12.2019]
 * @param {string} section
 * @param {IKeyValue | IKeyValue[]} data
 * @returns {TResult}
 */
exports.applySection = function (section, data) {
    return (__assign({ section: section }, (cond_1.ifNotEmptyThanValue(data, function () { return (Array.isArray(data)
        ? type_1.toType({ data: data })
        : data); }))));
};
/**
 * @stable [26.07.2020]
 * @param section
 */
exports.toActionPrefix = function (section) { return "" + definitions_interface_1.ACTION_PREFIX + section; };
/**
 * @stable [05.12.2019]
 * @param {IEffectsAction} action
 * @returns {string}
 */
exports.toSection = function (action) {
    return nvl_1.nvl(cond_1.ifNotNilThanValue(action.data, function (data) { return data.section; }), cond_1.ifNotNilThanValue(action.initialData, function (initialData) { return initialData.section; }));
};
/**
 * @stable [11.04.2020]
 * @param {SectionT<TState>} section
 * @param {IActionStateEntity<TState>} cfg
 * @returns {string}
 */
var toConfigSection = function (section, cfg) {
    return calc_1.calc(section, filter_1.defValuesFilter({ action: cfg.action, state: cfg.state }));
};
/**
 * @stable [11.04.2020]
 * @param {IListMiddlewareConfigEntity<TState> & IActionStateEntity<TState>} cfg
 * @returns {string}
 */
exports.toListSection = function (cfg) {
    return toConfigSection(cfg.listSection, cfg);
};
/**
 * @stable [11.04.2020]
 * @param {IContainerMiddlewareConfigEntity<TState> & IActionStateEntity<TState>} cfg
 * @returns {string}
 */
exports.toContainerSection = function (cfg) {
    return toConfigSection(cfg.containerSection, cfg);
};
/**
 * @stable [11.04.2020]
 * @param {IFormMiddlewareConfigEntity<TState> & IActionStateEntity<TState>} cfg
 * @returns {string}
 */
exports.toFormSection = function (cfg) {
    return toConfigSection(cfg.formSection, cfg);
};
/**
 * @stable [12.04.2020]
 * @param {ITabPanelMiddlewareConfigEntity<TState> & IActionStateEntity<TState>} cfg
 * @returns {string}
 */
exports.toTabPanelSection = function (cfg) {
    return toConfigSection(cfg.tabPanelSection, cfg);
};
/**
 * @stable [26.07.2020]
 */
var SectionUtils = /** @class */ (function () {
    function SectionUtils() {
    }
    SectionUtils.actionPrefix = exports.toActionPrefix;
    return SectionUtils;
}());
exports.SectionUtils = SectionUtils;
//# sourceMappingURL=section.js.map