"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var regexp_definition_interface_1 = require("../definition/regexp-definition.interface");
/**
 * @stable [02.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isDef = function (value) { return !exports.isUndef(value); };
/**
 * @stable [02.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isUndef = function (value) { return typeof value === 'undefined'; };
/**
 * @stable [02.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isFn = function (value) { return typeof value === 'function'; };
/**
 * @stable [01.08.2018]
 * @param {AnyT} value
 * @returns {boolean}
 */
var isNumber = function (value) { return typeof value === 'number' && !isNaN(value); };
/**
 * @stable [17.04.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isNotNumber = function (value) { return !isNumber(value); };
/**
 * @stable [06.12.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isDigit = function (value) { return isNumber(value) && regexp_definition_interface_1.RegexpConstants.POSITIVE_INTEGER.test(String(value)); };
/**
 * @stable [22.07.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
var isPositiveOrNegativeNumberLike = function (value) { return regexp_definition_interface_1.RegexpConstants.POSITIVE_OR_NEGATIVE_NUMBER.test("" + value); };
/**
 * @stable [06.12.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
var isBoolean = function (value) { return typeof value === 'boolean'; };
/**
 * @stable [17.05.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
var isString = function (value) { return typeof value === 'string'; };
/**
 * @stable [17.05.2020]
 * @param {AnyT} v
 * @returns {boolean}
 */
exports.isPrimitive = function (v) { return isNumber(v) || isString(v) || isBoolean(v); };
/**
 * @stable [18.05.2020]
 * @param {AnyT} v
 * @returns {boolean}
 */
var isObject = function (v) { return Object.prototype.toString.call(v) === '[object Object]'; };
/**
 * @stable [03.04.2020]
 * @param {AnyT} v
 * @returns {boolean}
 */
exports.isEvent = function (v) { return v instanceof Event; };
/**
 * @stable [06.12.2018]
 * @param {TResult} result
 * @returns {TResult}
 */
exports.toType = function (result) { return result; };
/**
 * @stable [16.05.2020]
 */
var TypeUtils = /** @class */ (function () {
    function TypeUtils() {
    }
    TypeUtils.isBoolean = isBoolean; /* @stable [12.06.2020] */
    TypeUtils.isDef = exports.isDef; /* @stable [16.05.2020] */
    TypeUtils.isFn = exports.isFn; /* @stable [16.05.2020] */
    TypeUtils.isNumber = isNumber; /* @stable [16.05.2020] */
    TypeUtils.isObject = isObject; /* @stable [16.05.2020] */
    TypeUtils.isPositiveOrNegativeNumberLike = isPositiveOrNegativeNumberLike; /* @stable [22.07.2020] */
    TypeUtils.isPrimitive = exports.isPrimitive; /* @stable [16.05.2020] */
    TypeUtils.isString = isString; /* @stable [16.05.2020] */
    TypeUtils.isUndef = exports.isUndef; /* @stable [16.05.2020] */
    return TypeUtils;
}());
exports.TypeUtils = TypeUtils;
//# sourceMappingURL=type.js.map