"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _a;
var R = require("ramda");
var type_1 = require("./type");
var definition_1 = require("../definition");
/**
 * @stable [29.07.2020]
 * @param value
 */
var positiveOrNegativeNumberLikeChecker = function (value) { return type_1.TypeUtils.isPositiveOrNegativeNumberLike(value); };
/**
 * @stable [06.12.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.optionalNumberLikeChecker = function (value) { return R.isNil(value) || positiveOrNegativeNumberLikeChecker(value); };
/**
 * @stable [06.12.2019]
 * @param value
 * @returns {boolean}
 */
exports.stringChecker = function (value) { return type_1.TypeUtils.isString(value); };
/**
 * @stable [06.12.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.notEmptyString = function (value) { return !R.isEmpty(value) && exports.stringChecker(value); };
/**
 * @stable [06.12.2019]
 * @param value
 * @returns {boolean}
 */
exports.digitChecker = function (value) { return type_1.isDigit(value); };
/**
 * @stable [28.01.2019]
 */
exports.ValidationRules = (_a = {},
    _a[definition_1.ValidatorRuleEnum.DIGIT] = exports.digitChecker,
    _a[definition_1.ValidatorRuleEnum.NOT_EMPTY_STRING] = exports.notEmptyString,
    _a[definition_1.ValidatorRuleEnum.OPTIONAL_NUMBER_LIKE] = exports.optionalNumberLikeChecker,
    _a[definition_1.ValidatorRuleEnum.POSITIVE_OR_NEGATIVE_NUMBER_LIKE] = positiveOrNegativeNumberLikeChecker,
    _a[definition_1.ValidatorRuleEnum.STRING] = exports.stringChecker,
    _a);
/**
 * @stable [17.04.2020]
 * @param {{[K in keyof TEntity]?: ValidatorRuleEnum[]}} payloads
 * @param {TEntity} checkedObject
 * @returns {IValidationResultEntity}
 */
exports.validate = function (payloads, checkedObject) {
    var data = Object.create(null);
    var valid = true;
    R.forEachObjIndexed(function (rules, fieldName) {
        var res = {};
        rules.forEach(function (ruleId) { return valid = valid && (res[ruleId] = exports.ValidationRules[ruleId](checkedObject[fieldName])); });
        data[fieldName] = res;
    }, payloads);
    return { valid: valid, data: data };
};
//# sourceMappingURL=validator.js.map