"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var value_1 = require("./value");
/**
 * @stable [08.06.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
var isValid = function (wrapper) {
    return R.isNil(wrapper)
        ? false
        : value_1.ValueUtils.isValueValid(wrapper.valid);
};
/**
 * @stable [03.02.2020]
 * @param {IFieldRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isFieldRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.fieldRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IPreventManualChangesWrapper} wrapper
 * @returns {boolean}
 */
var areManualChangesNotPrevented = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.preventManualChanges !== true;
};
/**
 * @stable [30.01.2020]
 * @param {IPreventFocusWrapper} wrapper
 * @returns {boolean}
 */
var isFocusPrevented = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.preventFocus === true;
};
/**
 * @stable [02.08.2020]
 * @param wrapper
 */
var inProgress = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.progress === true; };
/**
 * @stable [15.01.2020]
 * @param {TEntity} wrapper
 * @returns {boolean}
 */
exports.isCheckModalNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.checkModal === true;
};
/**
 * @stable [11.03.2020]
 * @param {IConfirmWrapper} wrapper
 * @returns {boolean}
 */
exports.isConfirm = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.confirm === true; };
/**
 * @stable [28.11.2019]
 * @param {IReadyWrapper} entity
 * @returns {boolean}
 */
exports.isReady = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.ready === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IFullWrapper} entity
 * @returns {boolean}
 */
exports.isFull = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.full !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IScrollableWrapper} entity
 * @returns {boolean}
 */
exports.isScrollable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.scrollable !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDefaultWrapper} entity
 * @returns {boolean}
 */
exports.isDefault = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.default !== false; }, false);
};
/**
 * @stable [11.05.2020]
 * @param {IOverlayWrapper} entity
 * @returns {boolean}
 */
exports.isOverlay = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.overlay === true; }, false);
};
/**
 * @stable [11.05.2020]
 * @param {IAcceptableWrapper} entity
 * @returns {boolean}
 */
exports.isAcceptable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.acceptable !== false; }, false);
};
/**
 * @stable [11.05.2020]
 * @param {IClosableWrapper} entity
 * @returns {boolean}
 */
exports.isClosable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.closable !== false; }, false);
};
/**
 * @stable [11.05.2020]
 * @param {IOverlayClosableWrapper} entity
 * @returns {boolean}
 */
exports.isOverlayClosable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.overlayClosable !== false; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IErrorWrapper} entity
 * @returns {boolean}
 */
exports.doesErrorExist = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () {
        return type_1.TypeUtils.isBoolean(entity.error)
            ? entity.error === true
            : !R.isNil(entity.error);
    }, false);
};
/**
 * @stable [06.03.2020]
 * @param {IRangeEnabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isRangeEnabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.rangeEnabled === true;
};
/**
 * @stable [26.10.2019]
 * @param {IEditedWrapper} editedEntity
 * @returns {boolean}
 */
exports.isEdited = function (editedEntity) {
    return cond_1.ifNotNilThanValue(editedEntity, function () { return editedEntity.edited === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {ISortableWrapper} wrapper
 * @returns {boolean}
 */
exports.isSortable = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.sortable === true; }, false);
};
/**
 * @stable [03.02.2020]
 * @param {IDisabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isDisabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.disabled === true;
};
/**
 * @stable [03.02.2020]
 * @param {ISelectedWrapper} wrapper
 * @returns {boolean}
 */
var isSelected = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.selected === true;
};
/**
 * @stable [03.02.2020]
 * @param {IExpandActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isExpandActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.expandActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {ICalendarActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isCalendarActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.calendarActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IClearActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isClearActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.clearActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IReadOnlyWrapper} wrapper
 * @returns {boolean}
 */
exports.isReadOnly = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.readOnly === true;
};
/**
 * @stable [22.01.2020]
 * @param {IInlineWrapper} wrapper
 * @returns {boolean}
 */
exports.isInline = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.inline === true; };
/**
 * @stable [11.05.2020]
 * @param {ICloseDisabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isCloseDisabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.closeDisabled === true;
};
/**
 * @stable [11.05.2020]
 * @param {IAcceptDisabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isAcceptDisabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.acceptDisabled === true;
};
/**
 * @stable [23.03.2020]
 * @param {IChangeableWrapper} wrapper
 * @returns {boolean}
 */
var isChangeable = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.changeable !== false;
};
/**
 * @stable [23.03.2020]
 * @param {IAlwaysResettableWrapper} wrapper
 * @returns {boolean}
 */
exports.isAlwaysResettable = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.alwaysResettable === true;
};
/**
 * @stable [21.06.2020]
 * @param {IUseCursorWrapper} wrapper
 * @returns {boolean}
 */
var isCursorUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.useCursor !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDecoratedWrapper} wrapper
 * @returns {boolean}
 */
var isDecorated = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.decorated !== false;
};
/**
 * @stable [13.11.2019]
 * @param {IMultiWrapper} wrapper
 * @returns {boolean}
 */
exports.isMulti = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.multi === true; }, false);
};
/**
 * @stable [16.01.2020]
 * @param {ITouchedWrapper} wrapper
 * @returns {boolean}
 */
var isTouched = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.touched === true; };
/**
 * @stable [08.08.2020]
 * @param wrapper
 */
var isAllowEmptyFilterValue = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.allowEmptyFilterValue !== false;
};
/**
 * @stable [26.11.2019]
 * @param {IPlaceActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isPlaceActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.placeActionRendered !== false;
};
/**
 * @stable [11.01.2020]
 * @param {IUseZipCodeWrapper} entity
 * @returns {boolean}
 */
exports.isUseZipCode = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.useZipCode === true; }, false);
};
/**
 * @stable [14.01.2020]
 * @param {IPlainValueWrapper} entity
 * @returns {boolean}
 */
var isPlainValueApplied = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.plainValue !== false; }, false);
};
/**
 * @stable [08.06.2020]
 * @param {IRefreshOnUpdateWrapper} wrapper
 * @returns {boolean}
 */
var isRefreshOnUpdateNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.refreshOnUpdate === true;
};
/**
 * @stable [28.01.2020]
 * @param {IDisplayValueRenderedOnlyWrapper} entity
 * @returns {boolean}
 */
exports.isDisplayValueRenderedOnly = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.displayValueRenderedOnly === true; }, false);
};
/**
 * @stable [23.04.2020]
 * @param {IAlwaysDirtyWrapper} entity
 * @returns {boolean}
 */
exports.isAlwaysDirty = function (entity) {
    return R.isNil(entity) ? false : entity.alwaysDirty === true;
};
/**
 * @stable [01.08.2020]
 * @param entity
 */
exports.isDirty = function (entity) {
    return R.isNil(entity) ? false : entity.dirty === true;
};
/**
 * @stable [16.02.2020]
 * @param {IErrorMessageRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isErrorMessageRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.errorMessageRendered !== false;
};
/**
 * @stable [15.03.2020]
 * @param {IOpenedWrapper} wrapper
 * @returns {boolean}
 */
exports.isOpened = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.opened === true;
};
/**
 * @stable [16.03.2020]
 * @param {IUsePreviewWrapper} wrapper
 * @returns {boolean}
 */
exports.isPreviewUsed = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.usePreview !== false;
};
/**
 * @stable [25.03.2020]
 * @param {IUsePeriodNavigatorWrapper} wrapper
 * @returns {boolean}
 */
exports.isPeriodNavigatorUsed = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.usePeriodNavigator === true;
};
/**
 * @stable [11.04.2020]
 * @param {INavigateBackWrapper} wrapper
 * @returns {boolean}
 */
exports.isNavigateBackNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.navigateBack !== false;
};
/**
 * @stable [18.05.2020]
 */
var WrapperUtils = /** @class */ (function () {
    function WrapperUtils() {
    }
    WrapperUtils.areManualChangesNotPrevented = areManualChangesNotPrevented; /* @stable [03.06.2020] */
    WrapperUtils.inProgress = inProgress; /* @stable [19.05.2020] */
    WrapperUtils.isAllowEmptyFilterValue = isAllowEmptyFilterValue; /* @stable [08.08.2020] */
    WrapperUtils.isChangeable = isChangeable; /* @stable [05.06.2020] */
    WrapperUtils.isClearActionRendered = isClearActionRendered; /* @stable [17.06.2020] */
    WrapperUtils.isCursorUsed = isCursorUsed; /* @stable [21.06.2020] */
    WrapperUtils.isDecorated = isDecorated; /* @stable [02.06.2020] */
    WrapperUtils.isDirty = exports.isDirty; /* @stable [01.08.2020] */
    WrapperUtils.isDisabled = exports.isDisabled; /* @stable [01.06.2020] */
    WrapperUtils.isErrorMessageRendered = isErrorMessageRendered; /* @stable [18.06.2020] */
    WrapperUtils.isExpandActionRendered = isExpandActionRendered; /* @stable [16.06.2020] */
    WrapperUtils.isFieldRendered = isFieldRendered; /* @stable [18.05.2020] */
    WrapperUtils.isFocusPrevented = isFocusPrevented; /* @stable [03.06.2020] */
    WrapperUtils.isFull = exports.isFull; /* @stable [20.05.2020] */
    WrapperUtils.isInline = exports.isInline; /* @stable [21.06.2020] */
    WrapperUtils.isPlainValueApplied = isPlainValueApplied; /* @stable [21.06.2020] */
    WrapperUtils.isReadOnly = exports.isReadOnly; /* @stable [18.06.2020] */
    WrapperUtils.isRefreshOnUpdateNeeded = isRefreshOnUpdateNeeded; /* @stable [08.06.2020] */
    WrapperUtils.isSelected = isSelected; /* @stable [01.06.2020] */
    WrapperUtils.isTouched = isTouched; /* @stable [18.05.2020] */
    WrapperUtils.isValid = isValid; /* @stable [05.06.2020] */
    return WrapperUtils;
}());
exports.WrapperUtils = WrapperUtils;
//# sourceMappingURL=wrapper.js.map