"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var R = require("ramda");
var util_1 = require("../../../util");
var di_1 = require("../../../di");
var definition_1 = require("../../../definition");
var TransportRequestPayloadFactory = /** @class */ (function () {
    /**
     * @stable [16.09.2019]
     */
    function TransportRequestPayloadFactory() {
        this.getBaseUrl = this.getBaseUrl.bind(this);
        this.getData = this.getData.bind(this);
    }
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @param {ITransportCancelTokenEntity} cancelToken
     * @returns {ITransportRequestPayloadEntity}
     */
    TransportRequestPayloadFactory.prototype.makeRequestPayload = function (requestEntity, cancelToken) {
        return util_1.notNilValuesFilter({
            url: this.getUrl(requestEntity),
            headers: this.getHeaders(requestEntity),
            method: this.getMethod(requestEntity),
            data: this.getData(requestEntity),
            cancelToken: cancelToken && cancelToken.token,
            withCredentials: this.getWithCredentials(requestEntity),
            responseType: util_1.coalesce(util_1.orUndef(requestEntity.blobResponse === true, function () { return definition_1.TransportResponseTypesEnum.BLOB; })),
        });
    };
    /**
     * @stable [16.09.2019]
     * @param {ITransportRequestEntity} req
     * @returns {IKeyValue}
     */
    TransportRequestPayloadFactory.prototype.makeRequestData = function (req) {
        return this.getRequestDataFactory(req).makeRequestData(req);
    };
    /**
     * @stable [16.09.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {string}
     */
    TransportRequestPayloadFactory.prototype.getUrl = function (requestEntity) {
        return util_1.isFn(requestEntity.urlFactory)
            ? requestEntity.urlFactory(requestEntity)
            : (util_1.buildTransportUrl({
                dataProvider: this.getData,
                dateNow: Date.now(),
                entity: requestEntity,
                settings: this.transportSettings,
                urlProvider: this.getBaseUrl,
            }));
    };
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} request
     * @returns {string}
     */
    TransportRequestPayloadFactory.prototype.getBaseUrl = function (request) {
        if (!R.isNil(request.url)) {
            return request.url;
        }
        var settings = this.settings.transport;
        var url = this.isRequestBlobData(request)
            ? util_1.nvl(settings.blobUrl, settings.apiUrl)
            : settings.apiUrl;
        return util_1.JoinUtils.join([url, request.path], ''); // URI's segment works incorrectly with a UUID (url.segment(req.path));
    };
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {boolean}
     */
    TransportRequestPayloadFactory.prototype.getWithCredentials = function (requestEntity) {
        return util_1.nvl(requestEntity.withCredentials, this.transportSettings.withCredentials);
    };
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {string}
     */
    TransportRequestPayloadFactory.prototype.getMethod = function (requestEntity) {
        return util_1.nvl(requestEntity.method, this.transportSettings.method);
    };
    /**
     * @stable [16.09.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {ITransportRequestDataFactory}
     */
    TransportRequestPayloadFactory.prototype.getRequestDataFactory = function (requestEntity) {
        return util_1.nvl(requestEntity.requestDataFactory, this.requestDataFactory);
    };
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {IKeyValue}
     */
    TransportRequestPayloadFactory.prototype.getData = function (requestEntity) {
        return requestEntity.formData
            || requestEntity.blobData
            || this.makeRequestData(requestEntity);
    };
    /**
     * @stable [16.09.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {IKeyValue}
     */
    TransportRequestPayloadFactory.prototype.getHeaders = function (requestEntity) {
        var transportSettings = this.transportSettings;
        var isBlobData = this.isRequestBlobData(requestEntity);
        var isFormData = this.isRequestFormData(requestEntity);
        var result = __assign({}, requestEntity.headers);
        if (isBlobData || isFormData) {
            var contentType = isBlobData
                ? transportSettings.blobDataContentType
                : transportSettings.formDataContentType;
            if (!R.isNil(contentType)) {
                result = __assign({}, result, { 'Content-Type': contentType });
            }
        }
        return util_1.ifNotEmptyThanValue(util_1.notNilValuesFilter(result), function (value) { return value; });
    };
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {boolean}
     */
    TransportRequestPayloadFactory.prototype.isRequestBlobData = function (requestEntity) {
        return util_1.isDef(requestEntity.blobData);
    };
    /**
     * @stable [16.09.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {boolean}
     */
    TransportRequestPayloadFactory.prototype.isRequestFormData = function (requestEntity) {
        return util_1.isDef(requestEntity.formData);
    };
    Object.defineProperty(TransportRequestPayloadFactory.prototype, "transportSettings", {
        /**
         * @stable [15.09.2019]
         * @returns {ITransportSettingsEntity}
         */
        get: function () {
            return this.settings.transport;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], TransportRequestPayloadFactory.prototype, "settings", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.TransportRequestDataFactory),
        __metadata("design:type", Object)
    ], TransportRequestPayloadFactory.prototype, "requestDataFactory", void 0);
    TransportRequestPayloadFactory = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], TransportRequestPayloadFactory);
    return TransportRequestPayloadFactory;
}());
exports.TransportRequestPayloadFactory = TransportRequestPayloadFactory;
//# sourceMappingURL=transport-request-payload-factory.service.js.map